#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='calendar'
APP='cal-china'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages. 

  -t, --translate VERSION LANGUAGE   
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate) 
if [ $# -lt 3 ]; then
    echo "Error: bad arguments or arguments not enough."
    echo "examples: $0 -t 24.1 zh_CN"
    echo "          $0 -t 24 zh_CN"
    exit 1 ;
fi
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi
	
## mkdir for translated .el files to save, for linux 
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows 
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

## for example:
#
#sed -i 's/"Sun\/Moon"/"太阳\/月亮"/g' $APP_PATH/${APP}.el
#sed -i 's/""/""/g' $APP_PATH/${APP}.el
sed -i 's/"Beijing"/"北京"/g' $APP_PATH/${APP}.el

#
# I really don't know what is PMT, mark first
#sed -i 's/"PMT"/""/g' $APP_PATH/${APP}.el

sed -i 's/"CST"/"CST 美国中部标准时间"/g' $APP_PATH/${APP}.el
sed -i 's/"CDT"/"CDT 美国中部夏令时间"/g' $APP_PATH/${APP}.el
sed -i 's/"GMT"/"GMT 格林尼治标准时间"/g' $APP_PATH/${APP}.el

# 10 total
sed -i 's/"Jia"/"甲"/g' $APP_PATH/${APP}.el
sed -i 's/"Yi"/"乙"/g' $APP_PATH/${APP}.el
sed -i 's/"Bing"/"丙"/g' $APP_PATH/${APP}.el
sed -i 's/"Ding"/"丁"/g' $APP_PATH/${APP}.el
sed -i 's/"Wu"/"戊"/g' $APP_PATH/${APP}.el
sed -i 's/"Ji"/"己"/g' $APP_PATH/${APP}.el
sed -i 's/"Geng"/"庚"/g' $APP_PATH/${APP}.el
sed -i 's/"Xin"/"辛"/g' $APP_PATH/${APP}.el
sed -i 's/"Ren"/"壬"/g' $APP_PATH/${APP}.el
sed -i 's/"Gui"/"癸"/g' $APP_PATH/${APP}.el

# 12 total
sed -i 's/"Zi"/"子"/g' $APP_PATH/${APP}.el
sed -i 's/"Chou"/"丑"/g' $APP_PATH/${APP}.el
sed -i 's/"Yin"/"寅"/g' $APP_PATH/${APP}.el
sed -i 's/"Mao"/"卯"/g' $APP_PATH/${APP}.el
sed -i 's/"Chen"/"辰"/g' $APP_PATH/${APP}.el
sed -i 's/"Si"/"巳"/g' $APP_PATH/${APP}.el
sed -i 's/"Wu"/"午"/g' $APP_PATH/${APP}.el
sed -i 's/"Wei"/"未"/g' $APP_PATH/${APP}.el
sed -i 's/"Shen"/"申"/g' $APP_PATH/${APP}.el
sed -i 's/"You"/"酉"/g' $APP_PATH/${APP}.el
sed -i 's/"Xu"/"戌"/g' $APP_PATH/${APP}.el
sed -i 's/"Hai"/"亥"/g' $APP_PATH/${APP}.el

#
sed -i 's/"Chinese New Year (%s)"/"中国农历新年(%s)"/g' $APP_PATH/${APP}.el
sed -i 's/"Qingming Festival"/"清明节"/g' $APP_PATH/${APP}.el

sed -i 's/"Winter Solstice Festival"/"冬至节"/g' $APP_PATH/${APP}.el

sed -i 's/"Cycle %s, year %s (%s), %smonth %s%s, day %s (%s)"/"周期%s, %s年(%s), %s%s月%s, %s日(%s)"/g' $APP_PATH/${APP}.el
sed -i 's/"Show the Chinese date equivalents of date."/"显示中国农历日期."/g' $APP_PATH/${APP}.el
sed -i 's/"Computing Chinese date..."/"计算农历..."/g' $APP_PATH/${APP}.el
sed -i 's/"Chinese date: %s"/"农历: %s"/g' $APP_PATH/${APP}.el
sed -i 's/"A list of the months in cycle C, year Y of the Chinese calendar."/"中国农历某年, 某个周期的月份列表"/g' $APP_PATH/${APP}.el
sed -i 's/"Chinese calendar cycle number (>44): "/"农历周期数字(>44): "/g' $APP_PATH/${APP}.el
sed -i 's/"Year in Chinese cycle (1..60): "/"农历年份(1..60): "/g' $APP_PATH/${APP}.el
sed -i 's/"Chinese calendar month: "/"农历月份: "/g' $APP_PATH/${APP}.el
sed -i 's/"Chinese calendar day (1-%d): "/"农历日(1-%d): "/g' $APP_PATH/${APP}.el
sed -i 's/"Chinese calendar equivalent of date diary entry."/"中国农历行程事项."/g' $APP_PATH/${APP}.el
#
sed -i 's/"Absolute date of first new moon on or after absolute date D."/"列出第一次新月出现的绝对日期, 或者某个绝对日期之后的新月."/g' $APP_PATH/${APP}.el
sed -i 's/"List of starting dates of Chinese months from START to END."/"列出中国农历月份的起始日期, 从年头到年尾."/g' $APP_PATH/${APP}.el

# note: in orig string, there's left " , but no right "
sed -i 's/"Compute the structure of the Chinese year for Gregorian year Y./"计算对应格里高利历法的中国农历年份./g' $APP_PATH/${APP}.el
#The result is a list of pairs (i d), where month i begins on absolute date d,
#of the Chinese months from the Chinese month following the solstice in
#Gregorian year Y-1 to the Chinese month of the solstice of Gregorian year Y."

# calendar-chinese-date-string
sed -i 's/"String of Chinese date of Gregorian DATE./"对应格里高利历法的中国农历字符串/g' $APP_PATH/${APP}.el
sed -i 's/Defaults to today'\''s date if DATE is not given."/如果没有指定日期, 默认为今天."/g' $APP_PATH/${APP}.el

#(defun calendar-chinese-zodiac-sign-on-or-after (d)
#  "Absolute date of first new Zodiac sign on or after absolute date D.
#The Zodiac signs begin when the sun's longitude is a multiple of 30 degrees."

#"Alist of Chinese year structures as determined by `chinese-year'.
#The default can be nil, but some values are precomputed for efficiency."

#(defun calendar-chinese-year (y)
#  "The structure of the Chinese year for Gregorian year Y.
#The result is a list of pairs (i d), where month i begins on absolute date d,
#of the Chinese months from the Chinese month following the solstice in
#Gregorian year Y-1 to the Chinese month of the solstice of Gregorian year Y.
#The list is cached in `calendar-chinese-year-cache' for further use."

#(defun calendar-chinese-year-cache-init (year)
#  "Insert an initialization value for `calendar-chinese-year-cache' after point.
#Computes values for 10 years either side of YEAR."

#(defun calendar-chinese-to-absolute (date)
#  "The number of days elapsed between the Gregorian date 12/31/1 BC and DATE.
#DATE is a Chinese date (cycle year month day).  The Gregorian date
#Sunday, December 31, 1 BC is imaginary."

#(defun calendar-chinese-from-absolute (date)
#  "Compute Chinese date (cycle year month day) corresponding to absolute DATE.
#The absolute date is the number of days elapsed since the (imaginary)
#Gregorian date Sunday, December 31, 1 BC."

#(defun holiday-chinese-new-year ()
#  "Date of Chinese New Year, if visible in calendar.
#Returns (((MONTH DAY YEAR) TEXT)), where the date is Gregorian."

#(defun holiday-chinese-qingming ()
#  "Date of Chinese Qingming Festival, if visible in calendar.
#Returns (((MONTH DAY YEAR) TEXT)), where the date is Gregorian."

#(defun holiday-chinese-winter-solstice ()
#  "Date of Chinese winter solstice, if visible in calendar.
#Returns (((MONTH DAY YEAR) TEXT)), where the date is Gregorian."

## (defun holiday-chinese (month day string)
#  "Holiday on Chinese MONTH, DAY called STRING.
#If MONTH, DAY (Chinese) is visible, returns the corresponding
#Gregorian date as the list (((month day year) STRING)).
#Returns nil if it is not visible in the current calendar window."

#sed -i 's/""/""/g' $APP_PATH/${APP}.el

### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."
cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el

## OPTIONAL MODULE
if [ $ENABLE_WIN_ICONV = "1" ];then
## for Emacs/Windows, some files such as
## lisp/international/mule-cmds.el
## lisp/language/chinese.el
## lisp/language/*.el
## calendar/lunar.el
## 
## and more any other files which may include non-ascii charactors should
## convert translated .el file to Windows UNICODE coding
## ( = utf-16le-with-signature in Emacs) to show local language text well,
## and never be utf-8, gbk/gb2312/gb18030 or any other codings..
## in some Emacs versions for Windows, utf-8 may works also ok, but for 
## simple and unify, we convert all to utf-16le-bom
	cd ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/
	iconv -f utf-8 -t UTF-16LE $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf-16le.el
	cat $FFFE $APP_PATH/${APP}_utf-16le.el > $APP_PATH/${APP}_utf-16le-bom.el  
	mv -fv $APP_PATH/${APP}_utf-16le-bom.el $APP_PATH/${APP}.el
## touch an empty file for remark	
	touch $APP_PATH/${APP}_utf-16le-with-signature.el
	rm -f $APP_PATH/${APP}_utf-16le.el
fi
## MODULE END	
## Emacs/Windows end

echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;
    
    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;
