#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='calendar'
APP='cal-menu'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages.

  -t, --translate VERSION LANGUAGE
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate)
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi
	
## mkdir for translated .el files to save, for linux
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

## for example:
#
sed -i 's/"Sun\/Moon"/"太阳\/月亮"/g' $APP_PATH/${APP}.el
sed -i 's/"Lunar Phases"/"月相"/g' $APP_PATH/${APP}.el
sed -i 's/"Sunrise\/sunset for cursor date"/"光标处日期的日出\/日落"/g' $APP_PATH/${APP}.el
sed -i 's/"Sunrise\/sunset for cursor month"/"光标处月份的日出\/日落"/g' $APP_PATH/${APP}.el
#sed -i 's/"Key map for \"Sun/Moon\" menu in the calendar."/""/g' $APP_PATH/${APP}.el
#
sed -i 's/"Diary"/"行程"/g' $APP_PATH/${APP}.el
sed -i 's/"Other File"/"其它文件"/g' $APP_PATH/${APP}.el
sed -i 's/"Cursor Date"/"光标处日期"/g' $APP_PATH/${APP}.el
sed -i 's/"Mark All"/"标记全部"/g' $APP_PATH/${APP}.el
sed -i 's/"Show All"/"显示全部"/g' $APP_PATH/${APP}.el
sed -i 's/"Insert Diary Entry"/"插入行程事项"/g' $APP_PATH/${APP}.el
 sed -i 's/"Insert Weekly"/"插入周事项"/g' $APP_PATH/${APP}.el
 sed -i 's/"Insert Monthly"/"插入月事项"/g' $APP_PATH/${APP}.el
 sed -i 's/"Insert Yearly"/"插入年事项"/g' $APP_PATH/${APP}.el
 sed -i 's/"Insert Anniversary"/"插入周年纪念日"/g' $APP_PATH/${APP}.el
 sed -i 's/"Insert Block"/"插入块"/g' $APP_PATH/${APP}.el
 sed -i 's/"Insert Cyclic"/"插入"/g' $APP_PATH/${APP}.el
 sed -i 's/"Insert Baha'\''i"/"插入巴海派"/g' $APP_PATH/${APP}.el

sed -i 's/"Bahá'\''í Date"/"巴海派日期"/g' $APP_PATH/${APP}.el
sed -i 's/"Insert Bahá'\''í"/"插入巴海派"/g' $APP_PATH/${APP}.el
sed -i 's/"Not on a date!"/"不在日期上!"/g' $APP_PATH/${APP}.el

 sed -i 's/"One time"/"一次"/g' $APP_PATH/${APP}.el
 sed -i 's/"Monthly"/"月周期"/g' $APP_PATH/${APP}.el
 sed -i 's/"Yearly"/"年周期"/g' $APP_PATH/${APP}.el
 sed -i 's/"Insert Islamic"/"插入伊斯兰教"/g' $APP_PATH/${APP}.el
 sed -i 's/"Insert Hebrew"/"插入希伯来"/g' $APP_PATH/${APP}.el
# sed -i 's/"Key map for \"Diary\" menu in the calendar."/""/g' $APP_PATH/${APP}.el

 sed -i 's/"Holidays"/"节假日"/g' $APP_PATH/${APP}.el
 sed -i 's/"For Cursor Date -"/"针对光标处日期 -"/g' $APP_PATH/${APP}.el
 sed -i 's/"For Window -"/"针对窗格 -"/g' $APP_PATH/${APP}.el
 sed -i 's/"For Today -"/"针对今天 -"/g' $APP_PATH/${APP}.el
 sed -i 's/"For Year %d"/"%d年"/g' $APP_PATH/${APP}.el
# sed -i 's/"hol-year-%d"/""/g' $APP_PATH/${APP}.el

# for 22.3
 sed -i 's/"For Cursor Date (%s)"/"针对光标处日期 -"/g' $APP_PATH/${APP}.el
 sed -i 's/"For Window (%s)"/"针对窗格 -"/g' $APP_PATH/${APP}.el
 sed -i 's/"For Today (%s)"/"针对今天 -"/g' $APP_PATH/${APP}.el
 sed -i 's/"For Year %s"/"%s年"/g' $APP_PATH/${APP}.el
# 22.3 end

 sed -i 's/"Unmark Calendar"/"取消标记日历"/g' $APP_PATH/${APP}.el
 sed -i 's/"Mark Holidays"/"标记节假日"/g' $APP_PATH/${APP}.el
# sed -i 's/"Key map for \"Holidays\" menu in the calendar."/""/g' $APP_PATH/${APP}.el

 sed -i 's/"Goto"/"转到"/g' $APP_PATH/${APP}.el
 sed -i 's/"Today"/"今天"/g' $APP_PATH/${APP}.el
 sed -i 's/"Beginning of Week"/"每周开始"/g' $APP_PATH/${APP}.el
 sed -i 's/"End of Week"/"周末"/g' $APP_PATH/${APP}.el
 sed -i 's/"Beginning of Month"/"月头"/g' $APP_PATH/${APP}.el
 sed -i 's/"End of Month"/"月尾"/g' $APP_PATH/${APP}.el
 sed -i 's/"Beginning of Year"/"年头"/g' $APP_PATH/${APP}.el
 sed -i 's/"End of Year"/"年尾"/g' $APP_PATH/${APP}.el
 sed -i 's/"Other Date"/"其它日期"/g' $APP_PATH/${APP}.el
 sed -i 's/"Day of Year"/"365 天"/g' $APP_PATH/${APP}.el
 sed -i 's/"ISO Week"/"ISO 周"/g' $APP_PATH/${APP}.el
 sed -i 's/"ISO Date"/"ISO 日期"/g' $APP_PATH/${APP}.el
 sed -i 's/"Astronomical Date"/"天文学日期"/g' $APP_PATH/${APP}.el
 sed -i 's/"Hebrew Date"/"希伯来日期"/g' $APP_PATH/${APP}.el
 sed -i 's/"Persian Date"/"波斯日期"/g' $APP_PATH/${APP}.el
 sed -i 's/"Baha'\''i Date"/"巴海派日期"/g' $APP_PATH/${APP}.el
 sed -i 's/"Islamic Date"/"伊斯兰教日期"/g' $APP_PATH/${APP}.el
 sed -i 's/"Julian Date"/"恺撒日期"/g' $APP_PATH/${APP}.el
 sed -i 's/"Chinese Date"/"中国日期"/g' $APP_PATH/${APP}.el
 sed -i 's/"Coptic Date"/"古埃及日期"/g' $APP_PATH/${APP}.el
 sed -i 's/"Ethiopic Date"/"埃塞俄比亚日期"/g' $APP_PATH/${APP}.el
 sed -i 's/"Mayan Date"/"玛雅日期"/g' $APP_PATH/${APP}.el
 sed -i 's/"Next Tzolkin"/"下一个 Tzolkin"/g' $APP_PATH/${APP}.el
 sed -i 's/"Previous Tzolkin"/"上一个 Tzolkin"/g' $APP_PATH/${APP}.el
 sed -i 's/"Next Haab"/"下一个 Haab"/g' $APP_PATH/${APP}.el
 sed -i 's/"Previous Haab"/"上一个 Haab"/g' $APP_PATH/${APP}.el
 sed -i 's/"Next Round"/"下一轮"/g' $APP_PATH/${APP}.el
 sed -i 's/"Previous Round"/"上一轮"/g' $APP_PATH/${APP}.el
 sed -i 's/"French Date"/"法国日期"/g' $APP_PATH/${APP}.el
# sed -i 's/"Key map for \"Goto\" menu in the calendar."/""/g' $APP_PATH/${APP}.el

# for 22.3
 sed -i 's/"ISO date: %s"/"ISO 日期: %s"/g' $APP_PATH/${APP}.el

 sed -i 's/"Julian date: %s"/"恺撒日期: %s"/g' $APP_PATH/${APP}.el

 sed -i 's/"Astronomical (Julian) day number (at noon UTC): %s.0"/"天文学(恺撒)日(在 UTC 中午): $s.0"/g' $APP_PATH/${APP}.el

# fuzzy,
 sed -i 's/"Fixed (RD) date: %s"/"固定的(RD)日期: %s"/g' $APP_PATH/${APP}.el

 sed -i 's/"Hebrew date (before sunset): %s"/"希伯来日期(日落之前): %s"/g' $APP_PATH/${APP}.el

 sed -i 's/"Persian date: %s"/"波斯日期: %s"/g' $APP_PATH/${APP}.el
 sed -i 's/"Baha'\''i date (before sunset): %s"/"巴海派日期(日落之前): %s"/g' $APP_PATH/${APP}.el
 sed -i 's/"Islamic dDate (before sunset): %s"/"伊斯兰教日期(日落之前): %s"/g' $APP_PATH/${APP}.el
 
 sed -i 's/"Islamic date (before sunset): %s"/"伊斯兰教日期(日落之前): %s"/g' $APP_PATH/${APP}.el
 
 sed -i 's/" (Gregorian)"/" (格里高历)"/g' $APP_PATH/${APP}.el  

 sed -i 's/"Chinese date: %s"/"中国日期: %s"/g' $APP_PATH/${APP}.el
 sed -i 's/"Coptic date: %s"/"古埃及日期: %s"/g' $APP_PATH/${APP}.el
 sed -i 's/"Ethiopic date: %s"/"埃塞俄比亚日期: %s"/g' $APP_PATH/${APP}.el
 sed -i 's/"Mayan date: %s"/"玛雅日期: %s"/g' $APP_PATH/${APP}.el

# fuzzy,
 sed -i 's/"French Revolutionary date: %s"/"法国大革命时期的日期: %s"/g' $APP_PATH/${APP}.el
# 22.3 end

 sed -i 's/"Scroll"/"翻页"/g' $APP_PATH/${APP}.el
 sed -i 's/"Forward 1 Day"/"向前1天"/g' $APP_PATH/${APP}.el
 sed -i 's/"Forward 1 Week"/"向前1周"/g' $APP_PATH/${APP}.el
 sed -i 's/"Forward 1 Month"/"向前1个月"/g' $APP_PATH/${APP}.el
 sed -i 's/"Forward 3 Months"/"向前3个月"/g' $APP_PATH/${APP}.el
 sed -i 's/"Forward 1 Year"/"向前1年"/g' $APP_PATH/${APP}.el
 sed -i 's/"Backward 1 Day"/"后退1天"/g' $APP_PATH/${APP}.el
 sed -i 's/"Backward 1 Week"/"后退1周"/g' $APP_PATH/${APP}.el
 sed -i 's/"Backward 1 Month"/"后退1个月"/g' $APP_PATH/${APP}.el
 sed -i 's/"Backward 3 Months"/"后退3个月"/g' $APP_PATH/${APP}.el
 sed -i 's/"Backward 1 Year"/"后退1年"/g' $APP_PATH/${APP}.el
# sed -i 's/"Key map for \"Scroll\" menu in the calendar."/""/g' $APP_PATH/${APP}.el
# "Call `x-popup-menu' at position EVENT, with TITLE and contents BODY.
#Signals an error if popups are unavailable."

#"Popup menus are not available on this system"
#"Pop up menu of diary entries for mouse-selected date.
#Use optional DATE and alternative file DIARY. EVENT is the event
#that invoked this command. Shows holidays if `diary-show-holidays-flag'
#is non-nil."

sed -i 's/"Diary entries%s for %s"/"行程事项 %s, 事由: %s"/g' $APP_PATH/${APP}.el

#sed -i 's/"Pop up menu for Mouse-2 for selected date in the calendar window."/""/g' $APP_PATH/${APP}.el
# sed -i 's/"cal-menu-mouse2"/""/g' $APP_PATH/${APP}.el

 sed -i 's/"Mark date"/"标记日期"/g' $APP_PATH/${APP}.el
#
sed -i 's/"Sunrise\/sunset"/"日出\/日落"/g' $APP_PATH/${APP}.el
#
sed -i 's/"Other calendars"/"其它日历"/g' $APP_PATH/${APP}.el
 sed -i 's/"Prepare LaTeX buffer"/"准备 LaTex 缓冲区"/g' $APP_PATH/${APP}.el
 sed -i 's/"Daily (1 page)"/"每天 (1页)"/g' $APP_PATH/${APP}.el
 sed -i 's/"Weekly (1 page)"/"每周 (1页)"/g' $APP_PATH/${APP}.el
 sed -i 's/"Weekly (2 pages)"/"每周 (2页)"/g' $APP_PATH/${APP}.el
 sed -i 's/"Weekly (other style; 1 page)"/"每周(其它风格; 1页)"/g' $APP_PATH/${APP}.el
 sed -i 's/"Weekly (yet another style; 1 page)"/"每周(另外一种风格; 1页)"/g' $APP_PATH/${APP}.el

 sed -i 's/"Monthly (landscape)"/"月周期 (横向)"/g' $APP_PATH/${APP}.el

 sed -i 's/"Yearly (landscape)"/"年周期 (横向)"/g' $APP_PATH/${APP}.el
 sed -i 's/"Filofax styles"/"Filofax 活页式风格"/g' $APP_PATH/${APP}.el
 sed -i 's/"Filofax Daily (one-day-per-page)"/"Filofax 活页式日事项(每天一页)"/g' $APP_PATH/${APP}.el
 sed -i 's/"Filofax Weekly (2-weeks-at-a-glance)"/"Filofax 活页式周事项(2周简略图)"/g' $APP_PATH/${APP}.el
 sed -i 's/"Filofax Weekly (week-at-a-glance)"/"Filofax 活页式周事项(1周简略图)"/g' $APP_PATH/${APP}.el
 sed -i 's/"Filofax Yearly"/"Filofax 活页式年事项"/g' $APP_PATH/${APP}.el
 sed -i 's/"Write HTML calendar"/"保存到 HTML 日历"/g' $APP_PATH/${APP}.el
 sed -i 's/"For selected month"/"针对选中的月份"/g' $APP_PATH/${APP}.el
 sed -i 's/"For selected year"/"针对选中的年份"/g' $APP_PATH/${APP}.el
 sed -i 's/"Diary entries"/"行程事项"/g' $APP_PATH/${APP}.el
 sed -i 's/"Insert diary entry"/"插入行程事项"/g' $APP_PATH/${APP}.el
 sed -i 's/"Other diary file entries"/"其它行程文件事项"/g' $APP_PATH/${APP}.el

# sed -i 's/"Menu bound to a mouse event, not specific to the mouse-click location."/""/g' $APP_PATH/${APP}.el
 sed -i 's/"Calendar"/"日历"/g' $APP_PATH/${APP}.el
 sed -i 's/"Scroll forward"/"向前翻页"/g' $APP_PATH/${APP}.el
 sed -i 's/"Scroll backward"/"往回翻页"/g' $APP_PATH/${APP}.el
 sed -i 's/"Mark diary entries"/"标记行程事项"/g' $APP_PATH/${APP}.el
 sed -i 's/"List holidays"/"列出节假日"/g' $APP_PATH/${APP}.el
 sed -i 's/"Mark holidays"/"标记节假日"/g' $APP_PATH/${APP}.el
 sed -i 's/"Unmark"/"取消标记"/g' $APP_PATH/${APP}.el

# for 22.3
 sed -i 's/"Moon"/"月亮"/g' $APP_PATH/${APP}.el
# 22.3 end

 sed -i 's/"Lunar phases"/"月相"/g' $APP_PATH/${APP}.el
 sed -i 's/"Sunrise times for month"/"某个月份的日出时间"/g' $APP_PATH/${APP}.el
 sed -i 's/"Show diary"/"显示行程"/g' $APP_PATH/${APP}.el
 sed -i 's/"Exit calendar"/"离开日历"/g' $APP_PATH/${APP}.el

# sed -i 's/"Hook run on loading of the `cal-menu' package."/""/g' $APP_PATH/${APP}.el
sed -i 's/"it will be removed in future."/"以后会被移除."/g' $APP_PATH/${APP}.el

sed -i 's/"None"/"无"/g' $APP_PATH/${APP}.el
sed -i 's/"Scroll Commands"/"翻页命令"/g' $APP_PATH/${APP}.el
# for 23.4
sed -i 's/"Motion Commands"/"提醒命令"/g' $APP_PATH/${APP}.el
# 23.4 end

sed -i 's/"Enter diary file name: "/"输入行程文件名: "/g' $APP_PATH/${APP}.el

sed -i 's/"Diary entries "/"行程事项 "/g' $APP_PATH/${APP}.el
sed -i 's/"Holidays for %s"/"节假日: %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Hebrew insert menu"/"希伯来插入菜单"/g' $APP_PATH/${APP}.el
sed -i 's/"Islamic insert menu"/"伊斯兰教插入菜单"/g' $APP_PATH/${APP}.el
sed -i 's/"Baha'\''i insert menu"/"巴海派插入菜单"/g' $APP_PATH/${APP}.el
sed -i 's/"Show holidays for today'\''s date."/"显示今天对应的节假日."/g' $APP_PATH/${APP}.el

#sed -i 's/"Commands that move point"/""/g' $APP_PATH/${APP}.el
#sed -i 's/"Commands that scroll the visible window"/""/g' $APP_PATH/${APP}.el

#sed -i 's/""/""/g' $APP_PATH/${APP}.el

### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."
cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el

MVER=$(echo "scale=0; $2 / 1" | bc)

## for Emacs 22.3 and earlier versions
	if [ $MVER <= 22 ]; then

	echo
	echo "do more for $NAME_UPPER $2/Windows..."
	cd ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/

	sed -i 's/cons \"月亮\"/cons \"Moon\"/g' $APP_PATH/${APP}.el
	sed -i 's/cons \"翻页\"/cons \"Scroll\"/g' $APP_PATH/${APP}.el
	sed -i 's/cons \"转到\"/cons \"Goto\"/g' $APP_PATH/${APP}.el
	sed -i 's/cons \"节假日\"/cons \"Holidays\"/g' $APP_PATH/${APP}.el
	sed -i 's/cons \"行程\"/cons \"Diary\"/g' $APP_PATH/${APP}.el
## touch another empty .el file with _windows mark for remark
	touch $APP_PATH/${APP}_windows.el

## OPTIONAL MODULE
if [ $ENABLE_WIN_ICONV = "1" ];then
## for Emacs/Windows, some files such as
## lisp/international/mule-cmds.el
## lisp/language/chinese.el
## lisp/language/*.el
## calendar/lunar.el
#
## and more any other files which may include non-ascii charactors should
## convert translated .el file to Windows UNICODE coding
## ( = utf-16le-with-signature in Emacs) to show local language text well,
## and never be utf-8, gbk/gb2312/gb18030 or any other codings..
## in some Emacs versions for Windows, utf-8 may works also ok, but for
## simple and unify, we convert all to utf-16le-bom
	iconv -f utf-8 -t UTF-16LE $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf-16le.el
	cat $FFFE $APP_PATH/${APP}_utf-16le.el > $APP_PATH/${APP}_utf-16le-bom.el
	mv -fv $APP_PATH/${APP}_utf-16le-bom.el $APP_PATH/${APP}.el
## touch an empty file for remark
	touch $APP_PATH/${APP}_utf-16le-with-signature.el
	rm -f $APP_PATH/${APP}_utf-16le.el
fi
## MODULE END	
	fi

## Emacs/Windows end

echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;

    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;
