#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='calendar'
APP='solar'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages. 

  -t, --translate VERSION LANGUAGE   
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate) 
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi
	
## mkdir for translated .el files to save, for linux 
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows 
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

## for example:
#sed -i 's/""/""/g' $APP_PATH/${APP}.el
sed -i 's/"Exact"/"精确的"/g' $APP_PATH/${APP}.el
sed -i 's/"Degrees"/"度"/g' $APP_PATH/${APP}.el
sed -i 's/"Minutes"/"分"/g' $APP_PATH/${APP}.el
sed -i 's/"Position"/"方位"/g' $APP_PATH/${APP}.el

sed -i 's/"Vernal Equinox"/"春分"/g' $APP_PATH/${APP}.el
sed -i 's/"Summer Solstice"/"夏至"/g' $APP_PATH/${APP}.el
sed -i 's/"Autumnal Equinox"/"秋分"/g' $APP_PATH/${APP}.el
sed -i 's/"Winter Solstice"/"冬至"/g' $APP_PATH/${APP}.el

sed -i 's/"Return sin of X degrees."/"返回 X 度 的正弦值(sin)。"/g' $APP_PATH/${APP}.el
sed -i 's/"Return cosine of X degrees."/"返回 X 度的余弦值(cos)。"/g' $APP_PATH/${APP}.el
sed -i 's/"Return tangent of X degrees."/"返回 X 度的正切值(tg)。"/g' $APP_PATH/${APP}.el
#sed -i 's/"Determine the quadrant of the point X, Y."/""/g' $APP_PATH/${APP}.el
#sed -i 's/"Arctangent of X in quadrant QUAD."/""/g' $APP_PATH/${APP}.el
sed -i 's/"Arctangent of point X, Y."/"点 X, Y 的反正切值。"/g' $APP_PATH/${APP}.el
sed -i 's/"Arccosine of X."/"X 的反余弦值。"/g' $APP_PATH/${APP}.el
sed -i 's/"Arcsin of Y."/"Y 的反正弦值。"/g' $APP_PATH/${APP}.el
sed -i 's/"Convert DEGREES to hours."/"把 DEGREES 角度换算成小时。"/g' $APP_PATH/${APP}.el
sed -i 's/"Convert HOUR to decimal fraction of a day."/"把 HOUR 小时换算成一天的10进制分数。"/g' $APP_PATH/${APP}.el

#sed -i 's/"Printable form for TIME expressed in hours."/""/g' $APP_PATH/${APP}.el
#sed -i 's/"Number of Julian centuries since 1 Jan, 2000 at noon UT for Gregorian DATE."/""/g' $APP_PATH/${APP}.el
#sed -i 's/"Equation of time expressed in hours at Gregorian DATE at Universal time UT."/""/g' $APP_PATH/${APP}.el

sed -i 's/"Sunrise"/"日出"/g' $APP_PATH/${APP}.el
sed -i 's/"Sunrise "/"日出 "/g' $APP_PATH/${APP}.el
sed -i 's/"No sunrise"/"没有日出"/g' $APP_PATH/${APP}.el
sed -i 's/"sunset"/"日落"/g' $APP_PATH/${APP}.el
sed -i 's/"sunset "/"日落 "/g' $APP_PATH/${APP}.el
sed -i 's/"no sunset"/"没有日落"/g' $APP_PATH/${APP}.el
sed -i 's/"Data used for calculation of solar longitude."/"用于计算太阳经度(longitude)的日期。"/g' $APP_PATH/${APP}.el

sed -i 's/"Enter longitude (decimal fraction; + east, - west): "/"输入10进制经度(longitude); + 代表东(E), - 代表西(W): "/g' $APP_PATH/${APP}.el
sed -i 's/"Enter latitude (decimal fraction; + north, - south): "/"输入10进制纬度(longitude); + 代表北(N), - 代表南(S): "/g' $APP_PATH/${APP}.el
sed -i 's/"Enter difference from Coordinated Universal Time (in minutes): "/"输入与坐标标准时间的时差(单位: 分钟): "/g' $APP_PATH/${APP}.el

# care with star *
sed -i 's/"\*temp\*"/"\*临时\*"/g' $APP_PATH/${APP}.el

#sed -i 's/"Local time of sunrise and sunset for month under cursor or at EVENT."/""/g' $APP_PATH/${APP}.el
sed -i 's/"Sunrise\/sunset times for %s %d at %s"/"%s %d 在 %s 的日出\/日落时间"/g' $APP_PATH/${APP}.el

sed -i 's/" at %s"/" 在 %s"/g' $APP_PATH/${APP}.el

sed -i 's/"%s, %s%s (%s hours daylight)"/"%s, %s%s(白天有%s小时)"/g' $APP_PATH/${APP}.el

#sed -i 's/""/""/g' $APP_PATH/${APP}.el

### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."
cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el

## OPTIONAL MODULE
if [ $ENABLE_WIN_ICONV = "1" ];then
## for Emacs/Windows, some files such as
## lisp/international/mule-cmds.el
## lisp/language/chinese.el
## lisp/language/*.el
## calendar/lunar.el
## 
## and more any other files which may include non-ascii charactors should
## convert translated .el file to Windows UNICODE coding
## ( = utf-16le-with-signature in Emacs) to show local language text well,
## and never be utf-8, gbk/gb2312/gb18030 or any other codings..
## in some Emacs versions for Windows, utf-8 may works also ok, but for 
## simple and unify, we convert all to utf-16le-bom
	cd ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/
	iconv -f utf-8 -t UTF-16LE $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf-16le.el
	cat $FFFE $APP_PATH/${APP}_utf-16le.el > $APP_PATH/${APP}_utf-16le-bom.el  
	mv -fv $APP_PATH/${APP}_utf-16le-bom.el $APP_PATH/${APP}.el
## touch an empty file for remark	
	touch $APP_PATH/${APP}_utf-16le-with-signature.el
	rm -f $APP_PATH/${APP}_utf-16le.el
fi
## MODULE END	
## Emacs/Windows end

echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;
    
    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;
