#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='.'
APP='dired'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages.

  -t, --translate VERSION LANGUAGE
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate)
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi
	
## mkdir for translated .el files to save, for linux
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

## for example:
#sed -i 's/""/""/g' $APP_PATH/${APP}.el
sed -i 's/"Directory editing."/"目录编辑。"/g' $APP_PATH/${APP}.el
sed -i 's/"Handling marks in Dired."/"Dired 列队中的处理标记"/g' $APP_PATH/${APP}.el
sed -i 's/"Subdir"/"子目录"/g' $APP_PATH/${APP}.el
sed -i 's/"Move to subdir"/"移动到子目录"/g' $APP_PATH/${APP}.el
sed -i 's/"Move to first"/"移动到第一个"/g' $APP_PATH/${APP}.el
sed -i 's/"Keep"/"保留"/g' $APP_PATH/${APP}.el
sed -i 's/"Hide All"/"全部隐藏"/g' $APP_PATH/${APP}.el

# care with /
sed -i 's/"Hide\/UnHide Subdir"/"隐藏\/取消隐藏子目录"/g' $APP_PATH/${APP}.el
#
sed -i 's/"Tree Down"/"树向下"/g' $APP_PATH/${APP}.el
sed -i 's/"Tree Up"/"树向上"/g' $APP_PATH/${APP}.el
sed -i 's/"Up Directory"/"上级目录"/g' $APP_PATH/${APP}.el
sed -i 's/"Prev Subdir"/"上一个子目录"/g' $APP_PATH/${APP}.el
sed -i 's/"Next Subdir"/"下一个子目录"/g' $APP_PATH/${APP}.el
sed -i 's/"Prev Dirline"/"上一个目录行"/g' $APP_PATH/${APP}.el
sed -i 's/"Next Dirline"/"下一个目录行"/g' $APP_PATH/${APP}.el
sed -i 's/"Insert This Subdir"/"插入这个子目录"/g' $APP_PATH/${APP}.el

sed -i 's/"Immediate"/"立即"/g' $APP_PATH/${APP}.el
sed -i 's/"Display Image Externally"/"在外部显示图像"/g' $APP_PATH/${APP}.el
sed -i 's/"Display Image"/"显示图像"/g' $APP_PATH/${APP}.el
sed -i 's/"Toggle Image Thumbnails in This Buffer"/"在这个缓冲区转换图像缩略图"/g' $APP_PATH/${APP}.el

sed -i 's/"Refresh"/"刷新"/g' $APP_PATH/${APP}.el
sed -i 's/"Isearch Regexp in File Names..."/"在文件名中渐进式搜索正则表达式..."/g' $APP_PATH/${APP}.el
sed -i 's/"Isearch in File Names..."/"在文件名中渐进式搜索..."/g' $APP_PATH/${APP}.el
sed -i 's/"Compare Directories..."/"比对目录..."/g' $APP_PATH/${APP}.el
sed -i 's/"Compare with Backup"/"和备份进行比对"/g' $APP_PATH/${APP}.el
sed -i 's/"Diff..."/"Diff 比对..."/g' $APP_PATH/${APP}.el
sed -i 's/"View This File"/"查看这个文件"/g' $APP_PATH/${APP}.el
sed -i 's/"Display in Other Window"/"在其它窗格中显示"/g' $APP_PATH/${APP}.el
sed -i 's/"Find in Other Window"/"在其它窗格中查找"/g' $APP_PATH/${APP}.el
sed -i 's/"Find This File"/"查找这个文件"/g' $APP_PATH/${APP}.el
sed -i 's/"Create Directory..."/"创建目录..."/g' $APP_PATH/${APP}.el
sed -i 's/"Edit File Names"/"编辑文件名"/g' $APP_PATH/${APP}.el

sed -i 's/"Regexp"/"表达式"/g' $APP_PATH/${APP}.el
sed -i 's/"Mark From Image Tag..."/"从图像 Tag 标签进行标记"/g' $APP_PATH/${APP}.el
sed -i 's/"Downcase"/"字母小写"/g' $APP_PATH/${APP}.el
sed -i 's/"Upcase"/"字母大写"/g' $APP_PATH/${APP}.el
sed -i 's/"Hardlink..."/"硬链接..."/g' $APP_PATH/${APP}.el
sed -i 's/"Symlink..."/"符号链接..."/g' $APP_PATH/${APP}.el
sed -i 's/"Rename..."/"重命名..."/g' $APP_PATH/${APP}.el
sed -i 's/"Copy..."/"复制..."/g' $APP_PATH/${APP}.el
sed -i 's/"Flag..."/"Flag 标定..."/g' $APP_PATH/${APP}.el

sed -i 's/"Mark..."/"标记..."/g' $APP_PATH/${APP}.el
sed -i 's/"Mark Containing..."/"标记包含特定条件的..."/g' $APP_PATH/${APP}.el
sed -i 's/"Mark"/"标记"/g' $APP_PATH/${APP}.el
sed -i 's/"Previous Marked"/"上一个标记的"/g' $APP_PATH/${APP}.el
sed -i 's/"Next Marked"/"下一个标记的"/g' $APP_PATH/${APP}.el
sed -i 's/"Change Marks..."/"更改标记..."/g' $APP_PATH/${APP}.el
sed -i 's/"Unmark All"/"全部取消标记"/g' $APP_PATH/${APP}.el
sed -i 's/"Mark Symlinks"/"标记符号链接"/g' $APP_PATH/${APP}.el
sed -i 's/"Mark Directories"/"标记目录"/g' $APP_PATH/${APP}.el
sed -i 's/"Mark Old Backups"/"标记旧的备份"/g' $APP_PATH/${APP}.el
sed -i 's/"Mark Executables"/"标记可执行的"/g' $APP_PATH/${APP}.el

sed -i 's/"Flag Garbage Files"/"Flag 标定垃圾文件"/g' $APP_PATH/${APP}.el
sed -i 's/"Flag Backup Files"/"Flag 标定备份文件"/g' $APP_PATH/${APP}.el
sed -i 's/"Flag Auto-save Files"/"Flag 标定自动保存文件"/g' $APP_PATH/${APP}.el
sed -i 's/"Flag"/"Flag 标定"/g' $APP_PATH/${APP}.el
sed -i 's/"Unmark"/"取消标记"/g' $APP_PATH/${APP}.el
sed -i 's/"Toggle Marks"/"转换标记"/g' $APP_PATH/${APP}.el

sed -i 's/"Operate"/"操作"/g' $APP_PATH/${APP}.el
sed -i 's/"Delete Image Tag..."/"删除图像 Tag 标识..."/g' $APP_PATH/${APP}.el
sed -i 's/"Add Image Tags..."/"添加图像 Tag 标识..."/g' $APP_PATH/${APP}.el
sed -i 's/"Add Image Comment..."/"图像注释..."/g' $APP_PATH/${APP}.el
sed -i 's/"Display Image Thumbnails"/"显示图像缩略图"/g' $APP_PATH/${APP}.el
sed -i 's/"Display image thumbnails"/"显示图像缩略图"/g' $APP_PATH/${APP}.el

sed -i 's/"Decrypt"/"解密"/g' $APP_PATH/${APP}.el
sed -i 's/"Verify"/"验证"/g' $APP_PATH/${APP}.el
sed -i 's/"Sign"/"签名"/g' $APP_PATH/${APP}.el
sed -i 's/"Encrypt"/"加密"/g' $APP_PATH/${APP}.el

sed -i 's/"Query Replace in Files..."/"在文件中查询替换..."/g' $APP_PATH/${APP}.el
sed -i 's/"Search Files..."/"搜索文件..."/g' $APP_PATH/${APP}.el
sed -i 's/"Isearch Regexp Files..."/"渐进式搜索正则表达式文件..."/g' $APP_PATH/${APP}.el
sed -i 's/"Isearch Files..."/"渐进式搜索文件..."/g' $APP_PATH/${APP}.el
sed -i 's/"Change Owner..."/"更改所有者..."/g' $APP_PATH/${APP}.el
sed -i 's/"Change Group..."/"更改分组..."/g' $APP_PATH/${APP}.el
sed -i 's/"Change Mode..."/"更改模式(权限)..."/g' $APP_PATH/${APP}.el
sed -i 's/"Change Timestamp..."/"更改时间戳"/g' $APP_PATH/${APP}.el
sed -i 's/"Load"/"加载"/g' $APP_PATH/${APP}.el
sed -i 's/"Byte-compile"/"字节编译(Byte-compile)"/g' $APP_PATH/${APP}.el
sed -i 's/"Compress"/"压缩"/g' $APP_PATH/${APP}.el
sed -i 's/"Print..."/"打印..."/g' $APP_PATH/${APP}.el
sed -i 's/"Hardlink to..."/"硬链接到..."/g' $APP_PATH/${APP}.el
sed -i 's/"Symlink to..."/"符号链接到..."/g' $APP_PATH/${APP}.el
sed -i 's/"Asynchronous Shell Command..."/""/g' $APP_PATH/${APP}.el
sed -i 's/"Shell Command..."/"Shell 命令..."/g' $APP_PATH/${APP}.el
sed -i 's/"Delete"/"删除"/g' $APP_PATH/${APP}.el
sed -i 's/"Rename to..."/"重命名为..."/g' $APP_PATH/${APP}.el
sed -i 's/"Copy to..."/"复制到..."/g' $APP_PATH/${APP}.el

sed -i 's/"Unrecognized line!  Check directory-listing-before-filename-regexp"/"无法识别的行! 请检查 directory-listing-before-filename-regexp"/g' $APP_PATH/${APP}.el

# care with \\[ , orig: type \\[dired-hide-subdir]
# \\[ (3 charactors), to \\\\\[ (6 charactors)
sed -i 's/"File line is hidden, type \\\\\[dired-hide-subdir] to unhide"/"文件行是隐藏的，输入 \\\\\[dired-hide-subdir] 取消隐藏"/g' $APP_PATH/${APP}.el
# care end

sed -i 's/"No file on this line"/"当前行没有文件"/g' $APP_PATH/${APP}.el

sed -i 's/"Last"/"最后"/g' $APP_PATH/${APP}.el
sed -i 's/"First"/"第一个"/g' $APP_PATH/${APP}.el
sed -i 's/"%s directory"/"%s 目录"/g' $APP_PATH/${APP}.el

sed -i 's/"Goto file: "/"跳转到文件: "/g' $APP_PATH/${APP}.el
sed -i 's/"No subdir-alist in %s"/"%s 中没有子目录 subdir-alist 列表"/g' $APP_PATH/${APP}.el
sed -i 's/"Delete non-empty directories"/"删除非空的目录"/g' $APP_PATH/${APP}.el
sed -i 's/"Yes"/"Yes--是"/g' $APP_PATH/${APP}.el
sed -i 's/"No--only delete empty directories"/"No--不，只删除空目录"/g' $APP_PATH/${APP}.el
sed -i 's/"Confirm for each directory"/"确认每个目录"/g' $APP_PATH/${APP}.el
sed -i 's/"Confirm for each top directory only"/"只确认每个顶目录"/g' $APP_PATH/${APP}.el
sed -i 's/"Recursively %s %s? "/"递归 %s %s? "/g' $APP_PATH/${APP}.el
sed -i 's/"(No deletions requested)"/"(无任何删除请求)"/g' $APP_PATH/${APP}.el

# care with star *
sed -i 's/" \*Deletions\*"/"\*删除\*"/g' $APP_PATH/${APP}.el
#
sed -i 's/"Trash"/"回收站"/g' $APP_PATH/${APP}.el
sed -i 's/"Delete"/"删除"/g' $APP_PATH/${APP}.el
#
sed -i 's/"%d of %d deletion%s failed"/"%d\/%d个删除 %s 失败 "/g' $APP_PATH/${APP}.el
#
sed -i 's/"(No deletions performed)"/"(未执行删除)"/g' $APP_PATH/${APP}.el

# care with star *
sed -i 's/" \*Marked Files\*"/"\*标记的文件\*"/g' $APP_PATH/${APP}.el
#
sed -i 's/"Move to the next marked file, wrapping around the end of the buffer."/"移动到下一个标记的文件，从缓冲区底部开始。"/g' $APP_PATH/${APP}.el
sed -i 's/"No next marked file"/"没有下一个已标记的文件"/g' $APP_PATH/${APP}.el
sed -i 's/"(Wraparound for next marked file)"/"(从头再查找下一个已标记的文件)"/g' $APP_PATH/${APP}.el

sed -i 's/"Move to the previous marked file, wrapping around the end of the buffer."/"移动到上一个标记的文件，从缓冲区底部开始。"/g' $APP_PATH/${APP}.el
sed -i 's/"History list of regular expressions used in Dired commands."/"在 Dired 列队命令中使用的正则表达式历史列表。"/g' $APP_PATH/${APP}.el

sed -i 's/" files (regexp): "/" 文件(表达式): "/g' $APP_PATH/${APP}.el
sed -i 's/"matching file"/"匹配的文件"/g' $APP_PATH/${APP}.el
sed -i 's/"Checking %s"/"检查 %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Change (old mark): "/"更改(旧标记): "/g' $APP_PATH/${APP}.el
sed -i 's/"Change %c marks to (new mark): "/"更改 %c 标记为(新标记): "/g' $APP_PATH/${APP}.el

# care with '
sed -i 's/"Unmark file `%s'\''? "/"取消标记文件 %s?"/g' $APP_PATH/${APP}.el
#
sed -i 's/"1 mark removed"/"1个标记的已移除"/g' $APP_PATH/${APP}.el
sed -i 's/"%d marks removed"/"%d个标记的已移除"/g' $APP_PATH/${APP}.el
sed -i 's/"%s--type ? for details (%s)"/"%s--输入 ? 查看详情 (%s)"/g' $APP_PATH/${APP}.el
sed -i 's/"%s--type ? for details"/"%s--输入 ? 查看详情"/g' $APP_PATH/${APP}.el

# care with ' , 2 times
sed -i 's/"Regexp recognized by Dired to set `by date'\'' mode."/"Dired 列队命令识别的正则表达式设置的模式为“按日期”。"/g' $APP_PATH/${APP}.el
sed -i 's/"Regexp recognized by Dired to set `by name'\'' mode."/"Dired 列队命令识别的正则表达式设置的模式为“按名称”。"/g' $APP_PATH/${APP}.el

sed -i 's/"Dired by name"/"按名称进行 Dired 列队"/g' $APP_PATH/${APP}.el
sed -i 's/"Dired by date"/"按日期进行 Dired 列队"/g' $APP_PATH/${APP}.el
sed -i 's/"Dired "/"Dired 列队 "/g' $APP_PATH/${APP}.el

sed -i 's/"Cannot sort this dired buffer"/"无法对这个已进行 dired 列队的缓冲区进行排序"/g' $APP_PATH/${APP}.el
sed -i 's/"Copy directories"/"复制目录"/g' $APP_PATH/${APP}.el
sed -i 's/"No recursive copies"/"不进行递归复制"/g' $APP_PATH/${APP}.el
sed -i 's/"Ask for each directory"/"询问每一个目录"/g' $APP_PATH/${APP}.el
sed -i 's/"Ask for each top directory only"/"只询问每一个顶目录"/g' $APP_PATH/${APP}.el
sed -i 's/"Copy directories without asking"/"复制目录而不进行询问"/g' $APP_PATH/${APP}.el

# care with \n and '
sed -i 's/"Dired recursive copies are currently disabled.\\nSee the variable `dired-recursive-copies'\''."/"Dired 列队递归复制目前已禁用。\\n请查看变量 dired-recursive-copies 。"/g' $APP_PATH/${APP}.el
#
sed -i 's/"What action?"/"进行什么操作？"/g' $APP_PATH/${APP}.el
sed -i 's/"Copy here"/"复制到这里"/g' $APP_PATH/${APP}.el
sed -i 's/"Move here"/"移动到这里"/g' $APP_PATH/${APP}.el
sed -i 's/"Link here"/"链接到这里"/g' $APP_PATH/${APP}.el
sed -i 's/"Cancel"/"取消"/g' $APP_PATH/${APP}.el

# care with '
sed -i 's/"Overwrite existing file `%s'\''? "/"覆盖已存在的文件 %s ?"/g' $APP_PATH/${APP}.el
sed -i 's/"Make backup for existing file `%s'\''? "/"对已存在的文件 %s 进行备份?"/g' $APP_PATH/${APP}.el
#
sed -i 's/"Auxiliary information to be saved in desktop file."/"将要保存到桌面文件的附加信息。"/g' $APP_PATH/${APP}.el

sed -i 's/"Buffer includes %d directories"/"缓冲区包含%d个目录"/g' $APP_PATH/${APP}.el
sed -i 's/"Recursive delete of %s? "/"对 %s 进行递归删除？"/g' $APP_PATH/${APP}.el

# the following 3 lines may not need to translate, mark first
#sed -i 's/"[%s %d files]"/"[%s %d个文件]"/g' $APP_PATH/${APP}.el
#sed -i 's/"[next %d files]"/"[接下来%d个文件]"/g' $APP_PATH/${APP}.el
#sed -i 's/"%c [%d files]"/"%c [%d个文件]"/g' $APP_PATH/${APP}.el
# mark end

sed -i 's/"Flag for deletion (regexp): "/"Flag 标定为删除(正则表达): "/g' $APP_PATH/${APP}.el
sed -i 's/"executable file"/"可执行文件"/g' $APP_PATH/${APP}.el
sed -i 's/"auto save file"/"自动保存文件"/g' $APP_PATH/${APP}.el
sed -i 's/"symbolic link"/"符号链接"/g' $APP_PATH/${APP}.el
sed -i 's/" files containing (regexp): "/" 包含(正则表达式)的文件: "/g' $APP_PATH/${APP}.el
sed -i 's/"directory file"/"目录文件"/g' $APP_PATH/${APP}.el
sed -i 's/"ls switches (must contain -l): "/"ls 开关(必须包含 -l): "/g' $APP_PATH/${APP}.el
sed -i 's/"Desktop: Directory %s no longer exists."/"桌面: 目录 %s 已经不存在。"/g' $APP_PATH/${APP}.el

sed -i 's/"Face used for symbolic links."/"符号链接使用的外观。"/g' $APP_PATH/${APP}.el
sed -i 's/"Face name used for symbolic links."/"符号链接使用的外观名称。"/g' $APP_PATH/${APP}.el
sed -i 's/"%s of %s deletions"/"%s \/ %s个删除"/g' $APP_PATH/${APP}.el
sed -i 's/"%d deletion%s done"/"%d个删除 %s 完成"/g' $APP_PATH/${APP}.el
sed -i 's/"Delete %s "/"删除 %s "/g' $APP_PATH/${APP}.el

# for 24.1
sed -i 's/"Use dired-listing-switches"/"使用 dired-listing-switches"/g' $APP_PATH/${APP}.el
sed -i 's/"Switches"/"开关"/g' $APP_PATH/${APP}.el
sed -i 's/"Check for --dired support"/"检查是否支持 --dired"/g' $APP_PATH/${APP}.el
sed -i 's/"Do not use --dired"/"不使用 --dired"/g' $APP_PATH/${APP}.el
sed -i 's/"Use --dired"/"使用 --dired"/g' $APP_PATH/${APP}.el

#sed -i 's/"wildcard"/"通配符"/g' $APP_PATH/${APP}.el
sed -i 's/"  wildcard "/"  通配符 "/g' $APP_PATH/${APP}.el

# 24.1 end

# for 22.3
sed -i 's/"Display Image-Dired"/"显示图像队列"/g' $APP_PATH/${APP}.el
# 22.3 end

#sed -i 's/""/""/g' $APP_PATH/${APP}.el

### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."
	cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el

MVER=$(echo "scale=0; $2 / 1" | bc)

## for Emacs 22.3 and earlier versions
	if [ $MVER <= 22 ]; then
	echo
	echo "do more for $NAME_UPPER $2/Windows..."
	cd ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/

# for 22.3 /windows
# L1417  orig text: (cons "Mark" (make-sparse-keymap "Mark")))
# keep the first `cons "Mark"' as English, and the followed
# `make-sparse-keymap "Mark"' either English or translated
# are ok (not display in menu)
#   the same to other strings
sed -i 's/cons \"操作\"/cons \"Operate\"/g' $APP_PATH/${APP}.el
sed -i 's/cons \"标记\"/cons \"Mark\"/g' $APP_PATH/${APP}.el
sed -i 's/cons \"表达式\"/cons \"Regexp\"/g' $APP_PATH/${APP}.el
sed -i 's/cons \"子目录\"/cons \"Subdir\"/g' $APP_PATH/${APP}.el
sed -i 's/cons \"立即\"/"cons \"Immediate\"/g' $APP_PATH/${APP}.el
## touch another empty .el file with _windows mark for remark
	touch $APP_PATH/${APP}_windows.el
	fi
# 22.3 /windows end

echo "Done."
## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;

    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;
