#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='.'
APP='facemenu'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages. 

  -t, --translate VERSION LANGUAGE   
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate) 
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi
	
## mkdir for translated .el files to save, for linux 
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows 
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

## for example:
#sed -i 's/""/""/g' $APP_PATH/${APP}.el
sed -i 's/"Face"/"外观"/g' $APP_PATH/${APP}.el
sed -i 's/"Other..."/"其它..."/g' $APP_PATH/${APP}.el
sed -i 's/"Foreground Color"/"前景色"/g' $APP_PATH/${APP}.el
sed -i 's/"Background Color"/"背景色"/g' $APP_PATH/${APP}.el
sed -i 's/"Special"/"指定"/g' $APP_PATH/${APP}.el
sed -i 's/"Remove Special"/"移除指定的"/g' $APP_PATH/${APP}.el
sed -i 's/"Intangible"/"模糊"/g' $APP_PATH/${APP}.el
sed -i 's/"Invisible"/"不可见"/g' $APP_PATH/${APP}.el
sed -i 's/"Read-Only"/"只读"/g' $APP_PATH/${APP}.el
sed -i 's/"Center"/"居中"/g' $APP_PATH/${APP}.el
sed -i 's/"Full"/"全部"/g' $APP_PATH/${APP}.el
sed -i 's/"Right"/"右"/g' $APP_PATH/${APP}.el
sed -i 's/"Left"/"左"/g' $APP_PATH/${APP}.el
sed -i 's/"Unfilled"/"不调整"/g' $APP_PATH/${APP}.el
sed -i 's/"Indentation"/"缩进"/g' $APP_PATH/${APP}.el
sed -i 's/"Indent Right Less"/"少向右缩进"/g' $APP_PATH/${APP}.el
sed -i 's/"Indent Right More"/"多向右缩进"/g' $APP_PATH/${APP}.el
sed -i 's/"Indent Less"/"少缩进"/g' $APP_PATH/${APP}.el
sed -i 's/"Indent More"/"多缩进"/g' $APP_PATH/${APP}.el
sed -i 's/"Display Colors"/"显示颜色"/g' $APP_PATH/${APP}.el
sed -i 's/"Display Faces"/"显示外观"/g' $APP_PATH/${APP}.el
sed -i 's/"Describe Properties"/"属性说明"/g' $APP_PATH/${APP}.el
sed -i 's/"Text Properties"/"文本属性"/g' $APP_PATH/${APP}.el
sed -i 's/"Remove Text Properties"/"移除文本属性"/g' $APP_PATH/${APP}.el
sed -i 's/"Remove Face Properties"/"移除外观属性"/g' $APP_PATH/${APP}.el
sed -i 's/"Justification"/"对齐"/g' $APP_PATH/${APP}.el
sed -i 's/"Special Properties"/"指定属性"/g' $APP_PATH/${APP}.el
sed -i 's/"Set face"/"设置外观"/g' $APP_PATH/${APP}.el
sed -i 's/"None"/"无"/g' $APP_PATH/${APP}.el
sed -i 's/"Use add-face"/"使用 add-face 添加外观"/g' $APP_PATH/${APP}.el
sed -i 's/"Use face"/"使用外观"/g' $APP_PATH/${APP}.el
sed -i 's/"Color: "/"颜色: "/g' $APP_PATH/${APP}.el
sed -i 's/"\*Colors\*"/"\*颜色\*"/g' $APP_PATH/${APP}.el
#
#sed -i 's/"Menu keymap for background colors."/""/g' $APP_PATH/${APP}.el
sed -i 's/"List all faces"/"列出全部外观"/g' $APP_PATH/${APP}.el
sed -i 's/"Foreground color: "/"前景色: "/g' $APP_PATH/${APP}.el
sed -i 's/"Background color: "/"背景色: "/g' $APP_PATH/${APP}.el

sed -i 's/"Color `%s'\'' undefined"/"颜色 %s 未定义"/g' $APP_PATH/${APP}.el
sed -i 's/"Select foreground color %s for subsequent insertion."/"为接下来的插入选择前景色 %s ."/g' $APP_PATH/${APP}.el
sed -i 's/"Select background color %s for subsequent insertion."/"为接下来的插入选择背景色 %s ."/g' $APP_PATH/${APP}.el

sed -i 's/"Color Name"/"颜色名"/g' $APP_PATH/${APP}.el
sed -i 's/"Red-Green-Blue"/"红-绿-蓝"/g' $APP_PATH/${APP}.el
sed -i 's/"Distance on RGB cube"/"RGB 调色板距离"/g' $APP_PATH/${APP}.el
sed -i 's/"Distance from Color"/"色彩距离"/g' $APP_PATH/${APP}.el
sed -i 's/"Source Color Name"/"来源颜色名称"/g' $APP_PATH/${APP}.el
sed -i 's/"Hue-Saturation-Value"/"HUE 色相饱和度数值"/g' $APP_PATH/${APP}.el
sed -i 's/"Distance on HSV cylinder"/"HSV 调色盘距离"/g' $APP_PATH/${APP}.el
sed -i 's/"Unsorted"/"未排序的"/g' $APP_PATH/${APP}.el

### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el

echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;
    
    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;
