#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_UNIX_REPLACE='1'
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='1'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='international'
APP='mule-cmds'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages.

  -t, --translate VERSION LANGUAGE
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate)
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi

## mkdir for translated .el files to save, for linux
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

#;;; mule-cmds.el --- commands for multilingual environment -*-coding: iso-2022-7bit -*-
## iconv encoding from iso-2022-7bit (= ISO-2022-JP)to utf-8 first, 
## or can't translate to other languages, or show in bad enconding

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
iconv -f ISO-2022-JP -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el


#sed -i 's/^;;; mule-cmds.el --- commands for multilingual environment -\*-coding: iso-2022-7bit/;;; mule-cmds.el --- commands for multilingual environment -\*-coding: utf-8/g' $APP_PATH/${APP}.el

## for example:
#sed -i 's/""/""/g' $APP_PATH/${APP}.el
sed -i 's/"Describe Language Environment"/"语言环境说明"/g' $APP_PATH/${APP}.el
sed -i 's/"Language environment"/"语言环境"/g' $APP_PATH/${APP}.el
sed -i 's/"Default"/"默认值"/g' $APP_PATH/${APP}.el
sed -i 's/"Set Language Environment"/"设置语言环境"/g' $APP_PATH/${APP}.el

sed -i 's/"Set Coding System"/"设置编码系统"/g' $APP_PATH/${APP}.el
sed -i 's/"Set Coding Systems"/"设置编码系统"/g' $APP_PATH/${APP}.el

sed -i 's/"For Next Command"/"用于下一次命令"/g' $APP_PATH/${APP}.el
sed -i 's/"For Saving This Buffer"/"用于保存当前缓冲区"/g' $APP_PATH/${APP}.el
sed -i 's/"For Reverting This File Now"/"用于立即重新加载当前文件"/g' $APP_PATH/${APP}.el
sed -i 's/"For File Name"/"用于文件名"/g' $APP_PATH/${APP}.el
sed -i 's/"For Keyboard"/"用于键盘"/g' $APP_PATH/${APP}.el
sed -i 's/"For Terminal"/"用于终端"/g' $APP_PATH/${APP}.el
sed -i 's/"For X Selections\/Clipboard"/"用于 X 选择\/剪贴板"/g' $APP_PATH/${APP}.el
sed -i 's/"For Next X Selection"/"用于下一次 X 选择"/g' $APP_PATH/${APP}.el
sed -i 's/"For I\/O with Subprocess"/"用于 I\/O 子进程"/g' $APP_PATH/${APP}.el
sed -i 's/"Mule (Multilingual Environment)"/"Mule(多国语言环境)"/g' $APP_PATH/${APP}.el

sed -i 's/"Toggle Input Method"/"切换输入法"/g' $APP_PATH/${APP}.el
sed -i 's/"Select Input Method..."/"选择输入法..."/g' $APP_PATH/${APP}.el
sed -i 's/"Describe Input Method"/"输入法说明"/g' $APP_PATH/${APP}.el

sed -i 's/"Show Multi-lingual Text"/"显示多国语言文本"/g' $APP_PATH/${APP}.el
sed -i 's/"Show Multilingual Sample Text"/"显示全部多国语言范例文本"/g' $APP_PATH/${APP}.el
sed -i 's/"Show All Multilingual Settings"/"显示全部多国语言设置"/g' $APP_PATH/${APP}.el

sed -i 's/"Describe Input Method..."/"输入法说明..."/g' $APP_PATH/${APP}.el
sed -i 's/"Describe Coding System..."/"编码系统说明..."/g' $APP_PATH/${APP}.el
sed -i 's/"List Character Sets"/"列出字符集"/g' $APP_PATH/${APP}.el
sed -i 's/"Show All of Mule Status"/"显示全部 Mule 多国语言状态"/g' $APP_PATH/${APP}.el

sed -i 's/"The other coding systems"/"其它编码系统"/g' $APP_PATH/${APP}.el
sed -i 's/"However, each of them"/"但是, 当中的每一种"/g' $APP_PATH/${APP}.el
#
# care with '
sed -i 's/" encountered characters it couldn'\''t encode:\\n"/" 有冲突的字符无法进行编码:\\n"/g' $APP_PATH/${APP}.el
#
sed -i 's/"  %s cannot encode these:"/"  %s 无法对这些进行编码:"/g' $APP_PATH/${APP}.el
sed -i 's/"\*Warning\*"/"\*警告\*"/g' $APP_PATH/${APP}.el
sed -i 's/"Bogus calling sequence"/"伪调用序列"/g' $APP_PATH/${APP}.el

# care with \n
sed -i 's/" language environment\\n\\n"/" 语言环境\\n\\n"/g' $APP_PATH/${APP}.el
#

sed -i 's/"Sample text:\\n  "/"范例文本:\\n  "/g' $APP_PATH/${APP}.el
#
sed -i 's/"Input methods (default " (car input-method) ")\\n"/"输入法 (default " (car input-method) ")\\n"/g' $APP_PATH/${APP}.el
#
sed -i 's/"Input methods:\\n"/"输入法:\\n"/g' $APP_PATH/${APP}.el
sed -i 's/"Character sets:\\n"/"字符集:\\n"/g' $APP_PATH/${APP}.el
# \n end

sed -i 's/"  nothing specific to "/"  未指定名称到 "/g' $APP_PATH/${APP}.el

## Languages: maybe all language below must keep as original English strings,
## and not need to translate
#sed -i 's/"Ethiopic"/"埃塞俄比亚语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Arabic"/"阿拉伯语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Belarusian"/"白俄罗斯文"/g' $APP_PATH/${APP}.el
#sed -i 's/"Bulgarian"/"保加利亚语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Tibetan"/"藏语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Welsh"/"威尔士语"/g' $APP_PATH/${APP}.el
#sed -i 's/"German"/"德语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Greek"/"希腊语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Spanish"/"西班牙语"/g' $APP_PATH/${APP}.el

#sed -i 's/"Esperanto"/"世界语"/g' $APP_PATH/${APP}.el
#sed -i 's/"French"/"法语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Hebrew"/"希伯来语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Croatian"/"克罗埃西亚文"/g' $APP_PATH/${APP}.el
#sed -i 's/"Italian"/"意大利语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Japanese"/"日语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Georgian"/"格鲁吉亚语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Kannada"/"印度坎那达语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Korean"/"韩语\/朝鲜语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Lao"/"老挝语"/g' $APP_PATH/${APP}.el

#sed -i 's/"Lithuanian"/"立陶宛语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Latvian"/"拉脱维亚语"/g' $APP_PATH/${APP}.el

#sed -i 's/"Cyrillic-ISO"/"古斯拉夫语\/西里尔语 Cyrillic-ISO"/g' $APP_PATH/${APP}.el
#sed -i 's/"Malayalam"/"马拉雅拉姆语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Dutch"/"荷兰语"/g' $APP_PATH/${APP}.el

#sed -i 's/"Romanian"/"罗马尼亚语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Russian"/"俄语"/g' $APP_PATH/${APP}.el

#sed -i 's/"Devanagari"/"梵文字母"/g' $APP_PATH/${APP}.el

#sed -i 's/"Slovak"/"斯洛伐克语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Slovenian"/"斯洛维尼亚文"/g' $APP_PATH/${APP}.el

#sed -i 's/"Swedish"/"瑞典语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Tajik"/"塔吉克族"/g' $APP_PATH/${APP}.el

#sed -i 's/"Thai"/"泰语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Turkish"/"土耳其语"/g' $APP_PATH/${APP}.el

#sed -i 's/"Ukrainian"/"乌克兰语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Vietnamese"/"越南语"/g' $APP_PATH/${APP}.el
#
#sed -i 's/"Chinese-CNS"/"繁体中文 Chinese-CNS"/g' $APP_PATH/${APP}.el
#sed -i 's/"Chinese-EUC-TW"/"繁体中文 Chinese-EUC-TW"/g' $APP_PATH/${APP}.el
#sed -i 's/"Chinese-Big5"/"繁体中文 Chinese-Big5"/g' $APP_PATH/${APP}.el
#sed -i 's/"Chinese-GB18030"/"简体中文 Chinese-GB18030"/g' $APP_PATH/${APP}.el

#sed -i 's/"Chinese-GBK"/"简体中文 Chinese-GBK"/g' $APP_PATH/${APP}.el
#sed -i 's/"Chinese-GB"/"简体中文 Chinese-GB"/g' $APP_PATH/${APP}.el
#sed -i 's/"Tamil"/"泰米尔语"/g' $APP_PATH/${APP}.el

#sed -i 's/"Czech"/"捷克语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Latin-1"/"拉丁语 Latin-1"/g' $APP_PATH/${APP}.el
#sed -i 's/"Latin-2"/"拉丁语 Latin-2"/g' $APP_PATH/${APP}.el
#sed -i 's/"Latin-3"/"拉丁语 Latin-3"/g' $APP_PATH/${APP}.el
#sed -i 's/"Latin-4"/"拉丁语 Latin-4"/g' $APP_PATH/${APP}.el
#sed -i 's/"Latin-5"/"拉丁语 Latin-5"/g' $APP_PATH/${APP}.el
#sed -i 's/"Latin-6"/"拉丁语 Latin-6"/g' $APP_PATH/${APP}.el
#sed -i 's/"Latin-7"/"拉丁语 Latin-7"/g' $APP_PATH/${APP}.el

#sed -i 's/"Latin-8"/"拉丁语 Latin-8"/g' $APP_PATH/${APP}.el
#sed -i 's/"Latin-9"/"拉丁语 Latin-9"/g' $APP_PATH/${APP}.el

#sed -i 's/"English"/"英语"/g' $APP_PATH/${APP}.el
#sed -i 's/"Chinese"/"中文"/g' $APP_PATH/${APP}.el
## languages end

sed -i 's/"Not a symbol: %s"/"不是一个符号: %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Not a char-table nor a file name: %s"/"即不是字符表, 也不是文件: %s"/g' $APP_PATH/${APP}.el

sed -i 's/"Unicode (name or hex): "/"Unicode (名称或16进制)"/g' $APP_PATH/${APP}.el
sed -i 's/"Not a Unicode character"/"不是一个 Unicode 字符"/g' $APP_PATH/${APP}.el
sed -i 's/"Not a Unicode character code: %S"/"不是一个 Unicode 字符代码: %S"/g' $APP_PATH/${APP}.el
sed -i 's/"Not a Unicode character code: 0x%X"/"不是一个 Unicode 字符代码: 0x%X"/g' $APP_PATH/${APP}.el

sed -i 's/"Charset"/"字符集"/g' $APP_PATH/${APP}.el
sed -i 's/"Set language environment (default English): "/"设置语言环境(默认为英语): "/g' $APP_PATH/${APP}.el
sed -i 's/"zPrefer coding system: "/"z优先使用编码系统: "/g' $APP_PATH/${APP}.el

# care with '
sed -i 's/"Can'\''t prefer the coding system `%s'\''"/"无法优先使用 %s 编码系统"/g' $APP_PATH/${APP}.el
sed -i 's/"Coding-system (default %s): "/"编码系统(默认为 %s): "/g' $APP_PATH/${APP}.el

sed -i 's/"Invalid coding system `%s'\''"/"无效的编码系统 %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Select coding system (default %s): "/"选择编码系统(默认为 %s): "/g' $APP_PATH/${APP}.el
sed -i 's/"Really proceed with writing? "/"确定要进行写入? "/g' $APP_PATH/${APP}.el
sed -i 's/"Canceled because the buffer was modified"/"已取消。因为缓冲区已修改。"/g' $APP_PATH/${APP}.el

sed -i 's/"All following characters are encodable by %s"/"后面的字符可以按 %s 进行编码"/g' $APP_PATH/${APP}.el
sed -i 's/"Highest priority is set to %s (base of %s)"/"最高优先级设为 %s (%s 的基准)"/g' $APP_PATH/${APP}.el
#
sed -i 's/"Always"/"总是"/g' $APP_PATH/${APP}.el
sed -i 's/"Never"/"从不"/g' $APP_PATH/${APP}.el

sed -i 's/"Coding system for following command (default %s): "/"接下来的命令使用的编码系统: (默认为 %s)"/g' $APP_PATH/${APP}.el
sed -i 's/"Coding system for following command: "/"接下来的命令使用的编码系统: "/g' $APP_PATH/${APP}.el
sed -i 's/"Command to execute with %s:"/"用 %s 来执行的命令"/g' $APP_PATH/${APP}.el
#
sed -i 's/"Save aborted"/"放弃保存"/g' $APP_PATH/${APP}.el
sed -i 's/"%s Environment"/"%s 环境"/g' $APP_PATH/${APP}.el
sed -i 's/"LEIM: Libraries of Emacs Input Methods."/"LEIM: 即 Emacs 输入法库 (Libraries of Emacs Input Methods)."/g' $APP_PATH/${APP}.el
sed -i 's/"Can'\''t activate input method `%s'\''"/"无法激活输入法“%s”"/g' $APP_PATH/${APP}.el

sed -i 's/"Input method (default %s): "/"输入法(默认为 %s): "/g' $APP_PATH/${APP}.el

sed -i 's/"Input method: "/"输入法: "/g' $APP_PATH/${APP}.el
sed -i 's/"Input method: %s (`%s'\'' in mode line) for %s\\n  %s\\n"/"输入法: %s (“%s”在状态栏)用于 %s\\n  %s\\n"/g' $APP_PATH/${APP}.el

sed -i 's/"Turn off the current input method."/"关闭当前的输入法。"/g' $APP_PATH/${APP}.el

sed -i 's/"No way to describe the current input method `%s'\''"/"无法对当前的“%s”输入法进行说明"/g' $APP_PATH/${APP}.el

sed -i 's/"No valid input method is specified"/"未指定有效的输入法"/g' $APP_PATH/${APP}.el

sed -i 's/"Describe input method (default current choice): "/"输入法说明(默认为当前选择): "/g' $APP_PATH/${APP}.el
sed -i 's/"No input method is activated now"/"现在未激活输入法"/g' $APP_PATH/${APP}.el
sed -i 's/"Select input method (default %s): "/"选择输入法(默认为 %s): "/g' $APP_PATH/${APP}.el
sed -i 's/"Select input method: "/"选择输入法: "/g' $APP_PATH/${APP}.el
sed -i 's/""/""/g' $APP_PATH/${APP}.el
sed -i 's/""/""/g' $APP_PATH/${APP}.el

sed -i 's/"Language environment not defined: %S"/"语言环境未定义: %S"/g' $APP_PATH/${APP}.el
sed -i 's/"Invalid charset: %S"/"无效的字符集: %S"/g' $APP_PATH/${APP}.el
sed -i 's/"Describe language environment (default current choice): "/"语言环境说明(默认为当前选择): "/g' $APP_PATH/${APP}.el
sed -i 's/"No documentation for the specified language"/"指定的语言没有文档"/g' $APP_PATH/${APP}.el
sed -i 's/"Coding systems:\\n"/"编码系统:\\n"/g' $APP_PATH/${APP}.el
sed -i 's/"'\'' in mode line):\\n\\t"/"'\'' 在状态栏):\\n\\t"/g' $APP_PATH/${APP}.el
sed -i 's/" in mode line)\\n"/" 在状态栏)\\n"/g' $APP_PATH/${APP}.el

#sed -i 's/""/""/g' $APP_PATH/${APP}.el

### for Emacs/Windows
### copy translated .el file to windows/ dir
	echo
	echo "for $NAME_UPPER $2/Windows..."

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/	
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el

### BODY END

### EXTRA WORK
## OPTIONAL MODULE
if [ $ENABLE_UNIX_REPLACE = "1" ];then
### IMPORTANT for unix 23.2-24.2
## replace 23.2 - 24.2 lisp/international/mule-cmds.el with 23.1, or  
## menu items show in English, not in translated language.
	case "$2" in
# INIT VALUE, FOR REPLACE $2 (VERSION) FILE WITH ${UNIX_REPLACE_VER} (VERSION)
		23.2 | 23.3 | 23.4 | 24.1 | 24.2) UNIX_REPLACE_VER='23.1' 

#UNIX_REPLACE ()
	echo
	echo "do more for $NAME_UPPER $2/Linux..."

# check for translated Emacs 23.2 lisp/*/*_23.2.el (first) or lisp/*/*.el (second)
	if [ -e ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/${UNIX_REPLACE_VER}/site-lisp/$3/lisp/$APP_PATH/${APP}_${UNIX_REPLACE_VER}.el ];then

        cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

# copy translated xxx.el to xxx_CURRENT_VERSION.el for backup first
    	cp -pfv $APP_PATH/${APP}.el $APP_PATH/${APP}_${2}.el

# copy translated xxx.REPLACE_VERSION.el to current version directory for backup
        cp -pfv ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/${UNIX_REPLACE_VER}/site-lisp/$3/lisp/$APP_PATH/${APP}_${UNIX_REPLACE_VER}.el $APP_PATH/${APP}_${UNIX_REPLACE_VER}.el

# replace
    	echo "replace $APP_PATH/${APP}.el with ${NAME_LOWER} ${UNIX_REPLACE_VER} translated ..."
        cp -pfv ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/${UNIX_REPLACE_VER}/site-lisp/$3/lisp/$APP_PATH/${APP}_${UNIX_REPLACE_VER}.el $APP_PATH/${APP}.el
    
    	elif [ -e ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/${UNIX_REPLACE_VER}/site-lisp/$3/lisp/$APP_PATH/${APP}.el ];then

        cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

# copy translated xxx.el to xxx_CURRENT_VERSION.el for backup first
    	cp -pfv $APP_PATH/${APP}.el $APP_PATH/${APP}_${2}.el

# copy translated xxx.REPLACE_VERSION.el to current version directory for backup
        cp -pfv ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/${UNIX_REPLACE_VER}/site-lisp/$3/lisp/$APP_PATH/${APP}.el $APP_PATH/${APP}_${UNIX_REPLACE_VER}.el
# replace
    	echo "replace $APP_PATH/${APP}.el with ${NAME_LOWER} ${UNIX_REPLACE_VER} translated ..."
        cp -pfv ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/${UNIX_REPLACE_VER}/site-lisp/$3/lisp/$APP_PATH/${APP}.el $APP_PATH/${APP}.el
        
	else 
# copy translated xxx.el to xxx_CURRENT_VERSION.el for backup first
    	cp -pfv $APP_PATH/${APP}.el $APP_PATH/${APP}_${2}.el	

# creat an empty file for notice and future replace
	touch $APP_PATH/${APP}_${UNIX_REPLACE_VER}.el
	
	echo -n "no $APP_PATH/${APP}_${UNIX_REPLACE_VER}.el or $APP_PATH/${APP}.el"
	echo -n " in ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/${UNIX_REPLACE_VER}/site-lisp/$3/lisp/ ."
	echo " Skip."	
	fi
	;;

	esac	
fi
## MODULE END
	
### Emacs/Unix end

## OPTIONAL MODULE
if [ $ENABLE_WIN_ICONV = "1" ];then
# if don't want to enable-win-iconv, skip all of following;
# and if want to do so, do next
	case "$2" in
		23.2 | 23.3 | 23.4 | 24.1 | 24.2) ENABLE_WIN_ICONV='1' 
	if [ $ENABLE_WIN_ICONV = "1" ];then

### do more for win_23.2 - 24.2
#
## for Emacs/Windows, some files such as
## lisp/international/mule-cmds.el
## lisp/language/chinese.el
## lisp/language/*.el
## calendar/lunar.el
##
## and more any other files which may include non-ascii charactors should
## convert translated .el file to Windows UNICODE coding
## ( = utf-16le-with-signature in Emacs) to display text well,
## and never be utf-8, gbk/gb2312/gb18030 or any other codings..
## in some Emacs versions for Windows, utf-8 may work also ok, but for
## simple and unify, we convert all to utf-16le-with-signature
		
# enable-win-iconv () {
	echo
	echo "do more for $NAME_UPPER $2/Windows..."

	cd ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/

	iconv -f utf-8 -t UTF-16LE $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf-16le.el
	cat $FFFE $APP_PATH/${APP}_utf-16le.el > $APP_PATH/${APP}_utf-16le-bom.el
	mv -fv $APP_PATH/${APP}_utf-16le-bom.el $APP_PATH/${APP}.el
## touch an empty file for remark
	touch $APP_PATH/${APP}_utf-16le-with-signature.el
	rm -f $APP_PATH/${APP}_utf-16le.el
	fi
	;;

	esac
fi
## MODULE END

## OPTIONAL MODULE
if [ $ENABLE_WIN_REPLACE = "1" ];then
	case "$2" in

# replace translated Emacs version 23.2-24.2 file with 23.1 translated for work well	
		23.2 | 23.3 | 23.4 | 24.1 | 24.2) WIN_REPLACE_VER='23.1' 
# replace-windows-WIN_REPLACE_VER () {

# check for optional translated Emacs REPLACE_VERSION lisp/*/*_REPLACE_VERSION.el (first) or lisp/*/*.el (second)
	if [ -e ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-${WIN_REPLACE_VER}/site-lisp/$3/lisp/$APP_PATH/${APP}_${WIN_REPLACE_VER}.el ];then

        cd ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/

# copy translated xxx.el to xxx_CURRENT_VERSION.el for backup first
    	cp -pfv $APP_PATH/${APP}.el $APP_PATH/${APP}_${2}.el

# copy translated xxx.REPLACE_VERSION.el to current version directory for backup
        cp -pfv ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-${WIN_REPLACE_VER}/site-lisp/$3/lisp/$APP_PATH/${APP}_${WIN_REPLACE_VER}.el $APP_PATH/${APP}_${WIN_REPLACE_VER}.el

# replace
    	echo "replace $APP_PATH/${APP}.el with ${NAME_LOWER} ${WIN_REPLACE_VER} translated ..."
        cp -pfv ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-${WIN_REPLACE_VER}/site-lisp/$3/lisp/$APP_PATH/${APP}_${WIN_REPLACE_VER}.el $APP_PATH/${APP}.el
    
    	elif [ -e ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-${WIN_REPLACE_VER}/site-lisp/$3/lisp/$APP_PATH/${APP}.el ];then
        cd ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/

# copy translated xxx.el to xxx_CURRENT_VERSION.el for backup first
    	cp -pfv $APP_PATH/${APP}.el $APP_PATH/${APP}_${2}.el

# copy translated xxx.REPLACE_VERSION.el to current version directory for backup
        cp -pfv ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-${WIN_REPLACE_VER}/site-lisp/$3/lisp/$APP_PATH/${APP}.el $APP_PATH/${APP}_${WIN_REPLACE_VER}.el
# replace
    	echo "replace $APP_PATH/${APP}.el with ${NAME_LOWER} ${WIN_REPLACE_VER} translated ..."
        cp -pfv ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-${WIN_REPLACE_VER}/site-lisp/$3/lisp/$APP_PATH/${APP}.el $APP_PATH/${APP}.el
        
	else 
# copy translated xxx.el to xxx_CURRENT_VERSION.el for backup first
    	cp -pfv $APP_PATH/${APP}.el $APP_PATH/${APP}_${2}.el	

# creat an empty file for notice and future replace
	touch $APP_PATH/${APP}_${WIN_REPLACE_VER}.el
	
	echo -n "no $APP_PATH/${APP}_${WIN_REPLACE_VER}.el or $APP_PATH/${APP}.el"
	echo -n " in ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-${WIN_REPLACE_VER}/site-lisp/$3/lisp/ ."
	echo " Skip."	
	fi
	;;

	esac	 	
fi
## MODULE END
	
## Emacs/Windows end
### EXTRA END

echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;

    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;

