#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='language'
APP='chinese'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages. 

  -t, --translate VERSION LANGUAGE   
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate) 
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi
	
## mkdir for translated .el files to save, for linux 
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows 
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

#;;; chinese.el --- support for Chinese -*- coding: iso-2022-7bit; -*-
## iconv encoding from iso-2022-7bit (= ISO-2022-CN-EXT) to utf-8 first, 
## or can't translate to other languages, or show in bad enconding

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
iconv -f ISO-2022-CN-EXT -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

#sed -i 's/^;;; chinese.el --- support for Chinese -\*- coding: iso-2022-7bit/;;; chinese.el --- support for Chinese -\*- coding: utf-8/g' $APP_PATH/${APP}.el
## for example:
# string "Chinese" don't need to translate for lisp/language/chinese.el
#sed -i 's/"Chinese"/"中文"/g' $APP_PATH/${APP}.el

### below new for lisp/language/chinese.el
sed -i 's/"Support for Chinese GB18030 character set."/"对中文 GB18030 字符集的支持。"/g' $APP_PATH/${APP}.el
sed -i 's/"Support for Chinese GBK character set."/"对中文 GBK 字符集的支持。"/g' $APP_PATH/${APP}.el
sed -i 's/"GBK encoding for Chinese (MIME:GBK)."/"中文 GBK 编码 (MIME:GBK)。"/g' $APP_PATH/${APP}.el
sed -i 's/"Support for Chinese Big5 character set."/"对繁体中文 Big5 字符集的支持。"/g' $APP_PATH/${APP}.el
sed -i 's/"Support for Chinese GB2312 character set."/"对简体中文 GB2312 字符集的支持。"/g' $APP_PATH/${APP}.el
sed -i 's/"BIG5 8-bit encoding for Chinese (MIME:Big5)"/"繁体中文 BIG5 的8位文字编码 (MIME:Big5)。"/g' $APP_PATH/${APP}.el
sed -i 's/"Hz\/ZW 7-bit encoding for Chinese GB2312 (MIME:HZ-GB-2312)."/"简体中文 GB2312 的 Hz\/ZW 7位字符编码 (MIME:HZ-GB-2312)。"/g' $APP_PATH/${APP}.el
sed -i 's/"BIG5-HKSCS 8-bit encoding for Chinese, Hong Kong supplement (MIME:Big5-HKSCS)"/"中文 BIG5-HKSCS 8位文字编码，香港提供 (MIME:Big5-HKSCS)"/g' $APP_PATH/${APP}.el
sed -i 's/"ISO 2022 based EUC encoding for Chinese CNS11643."/"基于 ISO 2022 的台湾 EUC 文字编码, 适用于繁体中文 CNS11643。"/g' $APP_PATH/${APP}.el
sed -i 's/"GB18030 encoding for Chinese (MIME:GB18030)."/"中文 GB18030 文字编码 (MIME:GB18030)。"/g' $APP_PATH/${APP}.el

sed -i 's/"ISO 2022 based EUC encoding for Chinese GB2312 (MIME:GB2312)."/"基于 ISO 2022 的台湾 EUC 文字编码, 适用于简体中文 GB2312 (MIME:GB2312)。"/g' $APP_PATH/${APP}.el
sed -i 's/"ISO 2022 based 7bit encoding for Chinese GB and CNS (MIME:ISO-2022-CN-EXT)."/"基于 ISO 2022 的7位文字编码, 适用于简体中文 GB 和繁体中文 CNS (MIME:ISO-2022-CN-EXT)。"/g' $APP_PATH/${APP}.el
sed -i 's/"ISO 2022 based 7bit encoding for Chinese GB and CNS (MIME:ISO-2022-CN)."/"基于 ISO 2022 的7位文字编码, 适用于简体中文 GB 和繁体中文 CNS (MIME:ISO-2022-CN)。"/g' $APP_PATH/${APP}.el

sed -i 's/"Chinese-GB18030"/"简体中文 Chinese-GB18030"/g' $APP_PATH/${APP}.el

sed -i 's/"Chinese-CNS"/"繁体中文 Chinese-CNS"/g' $APP_PATH/${APP}.el
sed -i 's/"Chinese-EUC-TW"/"繁体中文 Chinese-EUC-TW"/g' $APP_PATH/${APP}.el
sed -i 's/"Chinese-GB"/"简体中文 Chinese-GB"/g' $APP_PATH/${APP}.el
sed -i 's/"Chinese-GBK"/"简体中文 Chinese-GBK"/g' $APP_PATH/${APP}.el
sed -i 's/"Chinese-GB18030"/"简体中文 Chinese-GB18030"/g' $APP_PATH/${APP}.el
sed -i 's/"Chinese-BIG5"/"繁体中文 Chinese-BIG5"/g' $APP_PATH/${APP}.el

## ! please don't translate string "Chinese", or translated file not work.
#sed -i 's/"Chinese"/"中文"/g' $APP_PATH/${APP}.el
#sed -i 's/""/""/g' $APP_PATH/${APP}.el


### for Emacs/Windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/	
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el

## OPTIONAL MODULE
if [ $ENABLE_WIN_ICONV = "1" ];then
## pwd: cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

## for Emacs/Windows, some files such as
## lisp/international/mule-cmds.el
## lisp/language/chinese.el
## lisp/language/*.el
## calendar/lunar.el
## 
## and more any other files which may include non-ascii charactors should
## convert translated .el file to Windows UNICODE coding
## ( = utf-16le-with-signature in Emacs) to show local language text well,
## and never be utf-8, gbk/gb2312/gb18030 or any other codings..
## in some Emacs versions for Windows, utf-8 may works also ok, but for 
## simple and unify, we convert all to utf-16le-bom
	cd ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/
	iconv -f utf-8 -t UTF-16LE $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf-16le.el
	cat $FFFE $APP_PATH/${APP}_utf-16le.el > $APP_PATH/${APP}_utf-16le-bom.el  
	mv -fv $APP_PATH/${APP}_utf-16le-bom.el $APP_PATH/${APP}.el
## touch an empty file for remark	
	touch $APP_PATH/${APP}_utf-16le-with-signature.el
	rm -f $APP_PATH/${APP}_utf-16le.el
## Emacs/Windows end
fi
## MODULE END

echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;
    
    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;
