#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130204
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
SITE_LISP_CONTRIB='/usr/share/emacs/site-lisp/contrib'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'

#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_UNIX_REPLACE='0'
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
SHOW_TRANSED='1'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='language'
APP='ui-zh-cn'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages.

  -t, --translate VERSION LANGUAGE
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
case    "$option" in
    -t | --translate)

if [ $# -lt 3 ]; then
    echo "Error: bad arguments or arguments not enough."
    echo "example: $0 -t 24.1 zh_CN"
    exit 1 ;
fi

echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

### example for steps ###
## 1: copy source to ~/emacs-xx.x/lisp/language/ui-zh-cn.el
## 2-3-4: copy ui-zh-cn.el to site-lisp/zh_CN/lisp/language/ : 
##	  _new.orig.el (ok) & _new.el (need translate) 
##	  & _old.orig.el (need sed)
## 5: sed and translate _new.el
## 6: copy translated _new.el to _old.el
## 7-8: sed _old.orig.el & translate _old.el for 
##      modifing version remark and separator codes
## 9: rename translated _new.el to ui-zh-cn.el for Emacs 23.2 and later, or 
##    rename translated _old.el to ui-zh-cn.el for Emacs 23.1 and earlier
### example end ###

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/${APP_PATH}/ ];then
		mkdir -p ~/${NAME_LOWER}-$2/lisp/${APP_PATH}/
#		echo "Error: directory ~/${NAME_LOWER}-$2/lisp/ not found. Quit."
#		exit 1;
	fi

## mkdir for translated .el files to save, for linux
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## step 1: copy source ##
if [ -e $SITE_LISP_CONTRIB/${APP}.el ];then
        echo "copy source ${APP}.el ..."
	cp -pvf $SITE_LISP_CONTRIB/${APP}.el ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el
fi
## step 1 end ##

echo

## step 2-3-4 
## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -pf ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}_new.orig.el
	cp -pf ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}_new.el
	cp -pf ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}_old.orig.el

elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -pf ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/${APP}_new.orig.el
	cp -pf ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/${APP}_new.el
	cp -pf ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/${APP}_old.orig.el
else echo "file not found, skip."
	exit 1;
fi
## step 2-3-4 end ##

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

## step 5 ##
## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed

#cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
cat emacs-transor-sign.$3 $APP_PATH/${APP}_new.el > $APP_PATH/${APP}_utf8.el

#mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}_new.el

#sed -i 's/""/""/g' $APP_PATH/${APP}.el 

sed -i 's/"Toggle Menu Language"/"切换菜单语言"/g' $APP_PATH/${APP}_new.el 
sed -i 's/"English"/"英语"/g' $APP_PATH/${APP}_new.el 
sed -i 's/"English "/"英语 "/g' $APP_PATH/${APP}_new.el 
sed -i 's/"Chinese"/"中文"/g' $APP_PATH/${APP}_new.el 

sed -i 's/"English for Emacs (>= 23.x)"/"英语, 适用于 Emacs (>= 23.x)"/g' $APP_PATH/${APP}_new.el 
sed -i 's/"English for Emacs (<= 22.x)"/"英语, 适用于 Emacs (<= 22.x)"/g' $APP_PATH/${APP}_new.el 

sed -i 's/"Simplified Chinese (zh_CN) for Unix Emacs (>= 23.x)"/"简体中文 (zh_CN), 适用于 Unix Emacs (>= 23.x)"/g' $APP_PATH/${APP}_new.el 
#sed -i 's/"Simplified Chinese, China (zh_CN), for Unix Emacs 23.x and Later Versions"/"简体中文, 中国 (zh_CN), 适用于 Unix Emacs 23.x 和更新的版本"/g' $APP_PATH/${APP}_new.el 

sed -i 's/"Simplified Chinese (zh_CN) for Unix Emacs (<= 22.x)"/"简体中文 (zh_CN), 适用于 Unix Emacs (<= 22.x)"/g' $APP_PATH/${APP}_new.el 
#sed -i 's/"Simplified Chinese, China (zh_CN), for Unix Emacs 22.x and Earlier Versions"/"简体中文, 中国 (zh_CN), 适用于 Unix Emacs 22.x 和更早的版本"/g' $APP_PATH/${APP}_new.el 

sed -i 's/"Simplified Chinese (zh_CN) for Windows Emacs (>= 23.x)"/"简体中文 (zh_CN), 适用于 Windows Emacs (>= 23.x)"/g' $APP_PATH/${APP}_new.el 
#sed -i 's/"Simplified Chinese, China (zh_CN), for Windows Emacs 23.x and Later Versions"/"简体中文, 中国 (zh_CN), 适用于 Windows Emacs 23.x 和更新的版本"/g' $APP_PATH/${APP}_new.el 

sed -i 's/"Simplified Chinese (zh_CN) for Windows Emacs (<= 22.x)"/"简体中文 (zh_CN), 适用于 Windows Emacs (<= 22.x)"/g' $APP_PATH/${APP}_new.el 
#sed -i 's/"Simplified Chinese, China (zh_CN), for Windows Emacs 22.x and Earlier Versions"/"简体中文, 中国 (zh_CN), 适用于 Windows Emacs 22.x 和更早的版本"/g' $APP_PATH/${APP}_new.el 

## ensure _new.el not include bad old separator codes
##sed -i 's/^;; Current Version: /;; Newer Version: /g' $APP_PATH/${APP}_new.el 
##sed -i 's/^;; Last Version: /;; Current Version: /g' $APP_PATH/${APP}_new.el 
sed -i 's/^;menu-bar-separator)/menu-bar-separator)/g' $APP_PATH/${APP}_new.el 
sed -i 's/^'\''("--"))/;'\''("--"))/g' $APP_PATH/${APP}_new.el 

## step 5 end ##

## step 6 ##
cp -pf $APP_PATH/${APP}_new.el $APP_PATH/${APP}_old.el
## step 6 end ##

## step 7-8 ##
sed -i 's/^;; Current Version: /;; Newer Version: /g' $APP_PATH/${APP}_old.orig.el $APP_PATH/${APP}_old.el
sed -i 's/^;; Last Version: /;; Current Version: /g' $APP_PATH/${APP}_old.orig.el $APP_PATH/${APP}_old.el
sed -i 's/^menu-bar-separator)/;menu-bar-separator)/g' $APP_PATH/${APP}_old.orig.el $APP_PATH/${APP}_old.el
sed -i 's/^;'\''("--"))/'\''("--"))/g' $APP_PATH/${APP}_old.orig.el $APP_PATH/${APP}_old.el

## step 7-8 end ##

## step 9 ##
## $2 (=VERSION/MAJOR_VERSION), $3 (=LANGAUGE) 
## $MVER = MAJOR_VERSION

MVER=$(echo "scale=0; $2 / 1" | bc)

if [ $MVER -le 22 ] || [ $2 = 23.1 ]; then
	# for Emacs 22.x and earlier versions
	mv -vf $APP_PATH/${APP}_old.el $APP_PATH/${APP}.el
elif [ $MVER -ge 24 ] || [ $2 = 23.2 ] || [ $2 = 23.3 ] || [ $2 = 23.4 ] || [ $2 = 23 ] ; then
	##think 23 as 23.2 and later versions, not 23.1
	mv -vf $APP_PATH/${APP}_new.el $APP_PATH/${APP}.el
fi
## step 9 end ##

### for Emacs/Windows begain ###
### copy translated .el file to windows/ dir
	echo
	echo "* for $NAME_UPPER $2/Windows..."

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/	
cp -pvf $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/

if [ -e  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}_new.orig.el ]; then
cp -pvf $APP_PATH/${APP}_new.orig.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

if [ -e  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}_old.orig.el ]; then
cp -pvf $APP_PATH/${APP}_old.orig.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

if [ -e  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}_new.el ]; then
cp -pvf $APP_PATH/${APP}_new.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

if [ -e  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}_old.el ]; then
cp -pvf $APP_PATH/${APP}_old.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi
### BODY END

## OPTIONAL MODULE
if [ $ENABLE_WIN_ICONV = "1" ];then
## for Emacs/Windows, some files such as
## lisp/international/mule-cmds.el
## lisp/language/chinese.el
## lisp/language/*.el
## calendar/lunar.el
##
## and more any other files which may include non-ascii charactors should
## convert translated .el file to Windows UNICODE coding
## ( = utf-16le-with-signature in Emacs) to display text well,
## and never be utf-8, gbk/gb2312/gb18030 or any other codings..
## in some Emacs versions for Windows, utf-8 may work also ok, but for
## simple and unify, we convert all to utf-16le-with-signature
		
# win_iconv () {
	echo
	echo "* do more for $NAME_UPPER $2/Windows..."

	cd ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/

	iconv -f utf-8 -t UTF-16LE $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf-16le.el
	cat $FFFE $APP_PATH/${APP}_utf-16le.el > $APP_PATH/${APP}_utf-16le-bom.el
	mv -fv $APP_PATH/${APP}_utf-16le-bom.el $APP_PATH/${APP}.el
## touch an empty file for remark
	touch $APP_PATH/${APP}_utf-16le-with-signature.el
	rm -f $APP_PATH/${APP}_utf-16le.el
fi
## MODULE END

## Emacs/Windows end
### EXTRA END

echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}*.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}*.el &
fi
## MODULE END

	exit 0 ;;

    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1 ;;
    esac
done
exit 0 ;
exit 0 ;;
