#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='org'
APP='org'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages. 

  -t, --translate VERSION LANGUAGE   
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate) 
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi
	
## mkdir for translated .el files to save, for linux 
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows 
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
    cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

## for example:
sed -i 's/"Align"/"对齐"/g' $APP_PATH/${APP}.el
sed -i 's/"Next Field"/"下一区"/g' $APP_PATH/${APP}.el
sed -i 's/"Previous Field"/"上一区"/g' $APP_PATH/${APP}.el

sed -i 's/"Next Row"/"下一行"/g' $APP_PATH/${APP}.el
sed -i 's/"Blank Field"/"空白区"/g' $APP_PATH/${APP}.el
sed -i 's/"Edit Field"/"编辑区"/g' $APP_PATH/${APP}.el
sed -i 's/"Copy Field from Above"/"从上面复制区"/g' $APP_PATH/${APP}.el
sed -i 's/"Column"/"列"/g' $APP_PATH/${APP}.el
sed -i 's/"Move Column Left"/"列左移"/g' $APP_PATH/${APP}.el
sed -i 's/"Move Column Right"/"列右移"/g' $APP_PATH/${APP}.el
sed -i 's/"Delete Column"/"删除列"/g' $APP_PATH/${APP}.el
sed -i 's/"Insert Column"/"插入列"/g' $APP_PATH/${APP}.el
sed -i 's/"Row"/"行"/g' $APP_PATH/${APP}.el
sed -i 's/"Move Row Up"/"行上移"/g' $APP_PATH/${APP}.el
#

 sed -i 's/"Move Row Down"/"行下移"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Delete Row"/"删除行"/g' $APP_PATH/${APP}.el
 sed -i 's/"Insert Row"/"插入行"/g' $APP_PATH/${APP}.el
 sed -i 's/"Sort lines in region"/"区域内的行排序"/g' $APP_PATH/${APP}.el
# 
 sed -i 's/"Insert Hline"/"插入标题行"/g' $APP_PATH/${APP}.el 
#
 sed -i 's/"Rectangle"/"选区"/g' $APP_PATH/${APP}.el
 sed -i 's/"Copy Rectangle"/"复制选区"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Cut Rectangle"/"剪切选区"/g' $APP_PATH/${APP}.el
 sed -i 's/"Paste Rectangle"/"粘贴选区"/g' $APP_PATH/${APP}.el
 sed -i 's/"Fill Rectangle"/"调整选区"/g' $APP_PATH/${APP}.el
 
 sed -i 's/"Calculate"/"计算"/g' $APP_PATH/${APP}.el
 sed -i 's/"Set Column Formula"/"设置列公式"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Set Field Formula"/"设置区公式"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Edit Formulas"/"编辑公式"/g' $APP_PATH/${APP}.el 
 
 sed -i 's/"Recalculate line"/"重新计算行"/g' $APP_PATH/${APP}.el
 sed -i 's/"Recalculate all"/"全部重新计算"/g' $APP_PATH/${APP}.el
 sed -i 's/"Iterate all"/"全部重复 (Iterate)"/g' $APP_PATH/${APP}.el
 
 sed -i 's/"Toggle Recalculate Mark"/"切换重新计算标记"/g' $APP_PATH/${APP}.el 
 #
 sed -i 's/"Sum Column\/Rectangle"/"列\/区求和"/g' $APP_PATH/${APP}.el 
 #
 sed -i 's/"Which Column?"/"哪一栏?"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Debug Formulas"/"调试公式"/g' $APP_PATH/${APP}.el 
#
 sed -i 's/"Show Col\/Row Numbers"/"显示列号\/行号"/g' $APP_PATH/${APP}.el
#
 sed -i 's/"Create"/"创建"/g' $APP_PATH/${APP}.el 
			
 sed -i 's/"Convert Region"/"转换区域"/g' $APP_PATH/${APP}.el
 sed -i 's/"Import from File"/"从文件导入"/g' $APP_PATH/${APP}.el
 sed -i 's/"Export to File"/"导出到文件"/g' $APP_PATH/${APP}.el
 #
 sed -i 's/"Create\/Convert from\/to table.el"/"创建\/转换 table.el"/g' $APP_PATH/${APP}.el 
#
#sed -i 's/"Org"/"Org"
#
sed -i 's/"Show\/Hide"/"显示\/隐藏"/g' $APP_PATH/${APP}.el
#
sed -i 's/"Cycle Visibility"/"循环可见"/g' $APP_PATH/${APP}.el
 sed -i 's/"Cycle Global Visibility"/"全局循环可见"/g' $APP_PATH/${APP}.el
 sed -i 's/"Sparse Tree..."/"简明树..."/g' $APP_PATH/${APP}.el
 sed -i 's/"Reveal Context"/"展开上下文"/g' $APP_PATH/${APP}.el
 sed -i 's/"Show All"/"显示全部"/g' $APP_PATH/${APP}.el
 
 sed -i 's/"Subtree to indirect buffer"/"到间接缓冲区的子树"/g' $APP_PATH/${APP}.el
 
 sed -i 's/"New Heading"/"新标题"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Navigate Headings"/"标题导航"/g' $APP_PATH/${APP}.el
 sed -i 's/"Up"/"向上"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Next"/"下一个"/g' $APP_PATH/${APP}.el
 sed -i 's/"Previous"/"上一个"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Next Same Level"/"下一个同级"/g' $APP_PATH/${APP}.el
 sed -i 's/"Previous Same Level"/"上一个同级"/g' $APP_PATH/${APP}.el
 
 sed -i 's/"Jump"/"跳转"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Edit Structure"/"编辑结构"/g' $APP_PATH/${APP}.el
 sed -i 's/"Move Subtree Up"/"子树上移"/g' $APP_PATH/${APP}.el
 sed -i 's/"Move Subtree Down"/"子树下移"/g' $APP_PATH/${APP}.el
 
 sed -i 's/"Copy Subtree"/"复制子树"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Cut Subtree"/"剪切子树"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Paste Subtree"/"粘贴子树"/g' $APP_PATH/${APP}.el 
 
 sed -i 's/"Clone subtree, shift time"/"按住 Shift 键时克隆子树"/g' $APP_PATH/${APP}.el 
 
 sed -i 's/"Promote Heading"/"提升标题"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Promote Subtree"/"提升子树"/g' $APP_PATH/${APP}.el
 sed -i 's/"Demote Heading"/"下沉标题"/g' $APP_PATH/${APP}.el
 sed -i 's/"Demote Subtree"/"下沉子树"/g' $APP_PATH/${APP}.el
 #
 sed -i 's/"Sort Region\/Children"/"区域\/子区域排序"/g' $APP_PATH/${APP}.el 
 #
 sed -i 's/"Convert to odd levels"/"转换到偶数层"/g' $APP_PATH/${APP}.el 
#
 sed -i 's/"Convert to odd\/even levels"/"转换到偶数\/单数层"/g' $APP_PATH/${APP}.el
#
 sed -i 's/"Editing"/"编辑"/g' $APP_PATH/${APP}.el
 sed -i 's/"Emphasis..."/"强调..."/g' $APP_PATH/${APP}.el
 sed -i 's/"Edit Source Example"/"编辑源码样例"/g' $APP_PATH/${APP}.el 
 #
 sed -i 's/"Footnote new\/jump"/"脚注新建\/跳转"/g' $APP_PATH/${APP}.el
 #
 sed -i 's/"Footnote extra"/"附加的脚注"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Archive"/"存档"/g' $APP_PATH/${APP}.el
 sed -i 's/"Archive (default method)"/"存档(默认方式)"/g' $APP_PATH/${APP}.el
 
 sed -i 's/"Move Subtree to Archive file"/"移动子树到存档文件"/g' $APP_PATH/${APP}.el
 sed -i 's/"Toggle ARCHIVE tag"/"切换存档 ARCHIVE 的 tag 标识"/g' $APP_PATH/${APP}.el
 sed -i 's/"Move subtree to Archive sibling"/"移动子树到存档 Archive 的同级"/g' $APP_PATH/${APP}.el 
# for 23.1
 sed -i 's/"Move Subtree to Archive"/"移动子树到存档"/g' $APP_PATH/${APP}.el
 sed -i 's/"Toggle ARCHIVE tag"/"切换存档 ARCHIVE 的 tag 标识"/g' $APP_PATH/${APP}.el
 sed -i 's/"Move subtree to archive sibling"/"移动子树到存档 Archive 的同级"/g' $APP_PATH/${APP}.el 
#
 sed -i 's/"Check and Tag Children"/"检查并对子事项进行标识"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Sparse trees open ARCHIVE trees"/"按简明树方式打开存档树"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Cycling opens ARCHIVE trees"/"循环打开存档树"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Move subtree to archive sibling"/"移动子树到同级存档"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Move Subtree to Archive"/"移动子树到存档"/g' $APP_PATH/${APP}.el 
# 23.1 end

sed -i 's/"Hyperlinks"/"超链接"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Store Link (Global)"/"保存链接(全局)"/g' $APP_PATH/${APP}.el 
 sed -i 's/"find existing link to here"/"查找指向这里的链接"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Find existing link to here"/"查找指向这里的链接"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Insert Link"/"插入链接"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Follow Link"/"跟从链接"/g' $APP_PATH/${APP}.el 

 sed -i 's/"Next link"/"下一个链接"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Previous link"/"上一个链接"/g' $APP_PATH/${APP}.el 

 sed -i 's/"Descriptive Links"/"描述的链接 (Descriptive Links)"/g' $APP_PATH/${APP}.el

 sed -i 's/"Literal Links"/"表面的链接 (Literal Links)"/g' $APP_PATH/${APP}.el

 sed -i 's/"TODO Lists"/"待办列表"/g' $APP_PATH/${APP}.el
 sed -i 's/"TODO\/DONE\/-"/"待办\/完成\/-"/g' $APP_PATH/${APP}.el
 sed -i 's/"Select keyword"/"选择关键词"/g' $APP_PATH/${APP}.el
 sed -i 's/"Next keyword"/"下一个关键词"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Previous keyword"/"上一个关键词"/g' $APP_PATH/${APP}.el
 sed -i 's/"Complete Keyword"/"补齐关键词"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Next keyword set"/"下一个关键词集合"/g' $APP_PATH/${APP}.el
 sed -i 's/"Previous keyword set"/"上一个关键词集合"/g' $APP_PATH/${APP}.el
 sed -i 's/"Show TODO Tree"/"显示待办树"/g' $APP_PATH/${APP}.el
 sed -i 's/"Global TODO list"/"全局待办列表"/g' $APP_PATH/${APP}.el
 
 sed -i 's/"Enforce dependencies"/"强制依赖"/g' $APP_PATH/${APP}.el
 sed -i 's/"Settings for tree at point"/"树上某个点的设置"/g' $APP_PATH/${APP}.el
 sed -i 's/"Do Children sequentially"/"按顺序执行子项目 (Do Children sequentially)"/g' $APP_PATH/${APP}.el 

 sed -i 's/"Do Children parallel"/"并行执行子项目 (Do Children parallel)"/g' $APP_PATH/${APP}.el 

 sed -i 's/"Set Priority"/"设置优先级"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Priority Up"/"优先级上移"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Priority Down"/"优先级下移"/g' $APP_PATH/${APP}.el 
 
 sed -i 's/"Get news from all feeds"/"收取全部 feed 新邮件"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Go to the inbox of a feed..."/"转到 feed 收件箱..."/g' $APP_PATH/${APP}.el
 sed -i 's/"Customize feeds"/"自定义 feed"/g' $APP_PATH/${APP}.el
 sed -i 's/"TAGS and Properties"/"TAG 标识和属性"/g' $APP_PATH/${APP}.el
 sed -i 's/"Set Tags"/"设置 Tag 标识"/g' $APP_PATH/${APP}.el
 sed -i 's/"Change tag in region"/"更改区域内的 tag 标识"/g' $APP_PATH/${APP}.el
 
 sed -i 's/"Set property"/"设置属性"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Column view of properties"/"分栏方式查看属性"/g' $APP_PATH/${APP}.el
 sed -i 's/"Insert Column View DBlock"/"插入分栏查看栏目"/g' $APP_PATH/${APP}.el
 sed -i 's/"Dates and Scheduling"/"日期和计划"/g' $APP_PATH/${APP}.el
 sed -i 's/"Timestamp"/"时间戳"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Timestamp (inactive)"/"时间戳(非链接)"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Change Date"/"更改日期"/g' $APP_PATH/${APP}.el
 sed -i 's/"1 Day Later"/"1 天后"/g' $APP_PATH/${APP}.el 
 sed -i 's/"1 Day Earlier"/"1 天前"/g' $APP_PATH/${APP}.el
 sed -i 's/"1 ... Later"/"1 ... 后"/g' $APP_PATH/${APP}.el 
 sed -i 's/"1 ... Earlier"/"1 ... 前"/g' $APP_PATH/${APP}.el
 sed -i 's/"Compute Time Range"/"计算时间范围"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Schedule Item"/"计划事项"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Deadline"/"截止时间"/g' $APP_PATH/${APP}.el 
 #
 # keep English text for show well in Windows OS
 sed -i 's/"Custom time format"/"自定义时间格式 (Custom time format)"/g' $APP_PATH/${APP}.el 
#
 sed -i 's/"Goto Calendar"/"转到日历"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Date from Calendar"/"日历日期"/g' $APP_PATH/${APP}.el 
# 
 sed -i 's/"Start\/Restart Timer"/"启动\/重新启动计时器"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Pause\/Continue Timer"/"暂停\/继续计时器"/g' $APP_PATH/${APP}.el 
 #
 sed -i 's/"Stop Timer"/"停止计时器"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Insert Timer String"/"插入计时器字符串"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Insert Timer Item"/"插入计时器事项"/g' $APP_PATH/${APP}.el
 sed -i 's/"Logging work"/"记录工作"/g' $APP_PATH/${APP}.el
 sed -i 's/"Clock in"/"计时开始(Clock in)"/g' $APP_PATH/${APP}.el
 sed -i 's/"Switch task"/"转换任务"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Clock out"/"计时结束(Clock out)"/g' $APP_PATH/${APP}.el
 sed -i 's/"Clock cancel"/"取消计时"/g' $APP_PATH/${APP}.el 
 
 sed -i 's/"Mark as default task"/"标记为默认任务"/g' $APP_PATH/${APP}.el
 sed -i 's/"Clock in, mark as default"/"计时开始(Clock in), 标记为默认"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Goto running clock"/"转到正在计时的时钟"/g' $APP_PATH/${APP}.el 
 
 sed -i 's/"Display times"/"显示次数"/g' $APP_PATH/${APP}.el
 sed -i 's/"Create clock table"/"创建时间表"/g' $APP_PATH/${APP}.el
 
 sed -i 's/"Record DONE time"/"记录完成时间"/g' $APP_PATH/${APP}.el

sed -i 's/"Switching to %s will %s record a timestamp"/"转换到 %s 会 %s 记录时间戳"/g' $APP_PATH/${APP}.el

 sed -i 's/"Agenda Command..."/"行程命令..."/g' $APP_PATH/${APP}.el 
 sed -i 's/"Set Restriction Lock"/"设置限制锁"/g' $APP_PATH/${APP}.el 
 sed -i 's/"File List for Agenda"/"行程的文件列表"/g' $APP_PATH/${APP}.el
#
 sed -i 's/"Edit File List"/"编辑文件列表"/g' $APP_PATH/${APP}.el
#
 sed -i 's/"Add\/Move Current File to Front of List"/"添加\/移动当前文件到列表最前面"/g' $APP_PATH/${APP}.el
#
 sed -i 's/"Remove Current File from List"/"从列表中移除当前文件"/g' $APP_PATH/${APP}.el
 sed -i 's/"Cycle through agenda files"/"循环通过行程文件"/g' $APP_PATH/${APP}.el
 sed -i 's/"Occur in all agenda files"/"在所有行程中发生"/g' $APP_PATH/${APP}.el

#

 sed -i 's/"Special views current file"/"单独查看当前文件"/g' $APP_PATH/${APP}.el
 sed -i 's/"TODO Tree"/"树状显示待办事项"/g' $APP_PATH/${APP}.el
 sed -i 's/"Check Deadlines"/"检查截止时间"/g' $APP_PATH/${APP}.el
 sed -i 's/"Timeline"/"时间线"/g' $APP_PATH/${APP}.el
 #
 sed -i 's/"Tags\/Property tree"/"Tag 标识\/属性树"/g' $APP_PATH/${APP}.el
# for 23.1
 sed -i 's/"Tags Tree"/"Tag 标识树"/g' $APP_PATH/${APP}.el
# 23.1 end
 sed -i 's/"Export\/Publish..."/"导出\/发布..."/g' $APP_PATH/${APP}.el
#
# sed -i 's/""/"LaTeX"/g'
 sed -i 's/"Org CDLaTeX mode"/"Org CDLaTeX 模式"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Insert Environment"/"插入嵌套(Environment)"/g' $APP_PATH/${APP}.el
 sed -i 's/"Insert math symbol"/"插入数字符号"/g' $APP_PATH/${APP}.el
 sed -i 's/"Modify math symbol"/"修改数字符号"/g' $APP_PATH/${APP}.el 
 sed -i 's/"Insert citation"/"插入引用"/g' $APP_PATH/${APP}.el
 
 sed -i 's/"Export LaTeX fragments as images"/"导出 LaTeX 片段到图像"/g' $APP_PATH/${APP}.el
 
# sed -i 's/""/"MobileOrg"/g'
 sed -i 's/"Push Files and Views"/"推送文件和查看"/g' $APP_PATH/${APP}.el
 sed -i 's/"Get Captured and Flagged"/"获取已抓取和已进行过 Flag 标定的"/g' $APP_PATH/${APP}.el
 sed -i 's/"Find FLAGGED Tasks"/"查找已进行 Flag 标定的任务"/g' $APP_PATH/${APP}.el
 
 sed -i 's/"Setup"/"设置"/g' $APP_PATH/${APP}.el
 
 sed -i 's/"Documentation"/"文档"/g' $APP_PATH/${APP}.el
 sed -i 's/"Show Version"/"显示版本"/g' $APP_PATH/${APP}.el
 sed -i 's/"Info Documentation"/"Info 说明文档"/g' $APP_PATH/${APP}.el
 sed -i 's/"Customize"/"自定义"/g' $APP_PATH/${APP}.el
 sed -i 's/"Browse Org Group"/"浏览 Org 分组"/g' $APP_PATH/${APP}.el 
 
 sed -i 's/"Expand This Menu"/"展开这个菜单"/g' $APP_PATH/${APP}.el 

 sed -i 's/"Send bug report"/"发送缺陷报告"/g' $APP_PATH/${APP}.el
 #
 sed -i 's/"Refresh\/Reload"/"刷新\/重新加载"/g' $APP_PATH/${APP}.el
 #
#  for 23.1 
 sed -i 's/"Refresh setup"/"刷新设置"/g' $APP_PATH/${APP}.el
sed -i 's/"Set"/"设置"/g' $APP_PATH/${APP}.el
sed -i 's/"Save"/"保存"/g' $APP_PATH/${APP}.el
sed -i 's/"Reset to Current"/"重设为当前值"/g' $APP_PATH/${APP}.el
sed -i 's/"Reset to Saved"/"重设为已保存的"/g' $APP_PATH/${APP}.el
sed -i 's/"Reset to Standard Settings"/"重设为标准设置"/g' $APP_PATH/${APP}.el

#sed -i 's/""/""/g' $APP_PATH/${APP}.el
#
sed -i 's/"Refresh setup current buffer"/"刷新设置当前缓冲区"/g' $APP_PATH/${APP}.el
 sed -i 's/"Reload Org (after update)"/"(在更新后)重新加载 Org"/g' $APP_PATH/${APP}.el
 sed -i 's/"Reload Org uncompiled"/"重新加载未编译的 Org"/g' $APP_PATH/${APP}.el
#
# for 24.1
sed -i 's/"Template for BEAMER"/"BEAMER 模板"/g' $APP_PATH/${APP}.el
sed -i 's/"Copy visible text"/"复制可见文本"/g' $APP_PATH/${APP}.el
# 24.1 end

#sed -i 's/""/""/g' $APP_PATH/${APP}.el

### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."
cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/	
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;
    
    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;
