#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='.'
APP='outline'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages. 

  -t, --translate VERSION LANGUAGE   
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate) 
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi
	
## mkdir for translated .el files to save, for linux 
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows 
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

## for example:
#
sed -i 's/"Hide"/"隐藏"/g' $APP_PATH/${APP}.el
sed -i 's/"Hide Other"/"隐藏其它"/g' $APP_PATH/${APP}.el
sed -i 's/"Hide Sublevels"/"隐藏下级"/g' $APP_PATH/${APP}.el
sed -i 's/"Hide Subtree"/"隐藏子树"/g' $APP_PATH/${APP}.el
sed -i 's/"Hide Entry"/"隐藏条目"/g' $APP_PATH/${APP}.el
sed -i 's/"Hide Body"/"隐藏正文"/g' $APP_PATH/${APP}.el
sed -i 's/"Hide Leaves"/"隐藏末端"/g' $APP_PATH/${APP}.el

sed -i 's/"Show"/"显示"/g' $APP_PATH/${APP}.el
sed -i 's/"Show Subtree"/"显示子树"/g' $APP_PATH/${APP}.el
sed -i 's/"Show Children"/"显示下级"/g' $APP_PATH/${APP}.el
sed -i 's/"Show Branches"/"显示分支"/g' $APP_PATH/${APP}.el
sed -i 's/"Show Entry"/"显示条目"/g' $APP_PATH/${APP}.el
sed -i 's/"Show All"/"显示全部"/g' $APP_PATH/${APP}.el

sed -i 's/"Headings"/"标题"/g' $APP_PATH/${APP}.el

sed -i 's/"Demote subtree"/"降级子树"/g' $APP_PATH/${APP}.el
sed -i 's/"Demote Subtree"/"降级子树"/g' $APP_PATH/${APP}.el
sed -i 's/"Promote subtree"/"提升子树"/g' $APP_PATH/${APP}.el
sed -i 's/"Promote Subtree"/"提升子树"/g' $APP_PATH/${APP}.el

sed -i 's/"Move subtree down"/"子树下移"/g' $APP_PATH/${APP}.el
sed -i 's/"Move Subtree Down"/"子树下移"/g' $APP_PATH/${APP}.el
sed -i 's/"Move subtree up"/"子树上移"/g' $APP_PATH/${APP}.el
sed -i 's/"Move Subtree Up"/"子树上移"/g' $APP_PATH/${APP}.el

sed -i 's/"Copy to kill ring"/"复制到剪贴板(即 kill ring)"/g' $APP_PATH/${APP}.el
sed -i 's/"Copy to Kill Ring"/"复制到剪贴板(即 Kill Ring)"/g' $APP_PATH/${APP}.el
sed -i 's/"New heading"/"新建标题"/g' $APP_PATH/${APP}.el
sed -i 's/"New Heading"/"新建标题"/g' $APP_PATH/${APP}.el

sed -i 's/"Previous Same Level"/"上一个同级"/g' $APP_PATH/${APP}.el
sed -i 's/"Next Same Level"/"下一个同级"/g' $APP_PATH/${APP}.el
sed -i 's/"Previous"/"上一个"/g' $APP_PATH/${APP}.el
sed -i 's/"Next"/"下一个"/g' $APP_PATH/${APP}.el
sed -i 's/"Up"/"上移"/g' $APP_PATH/${APP}.el
sed -i 's/"Down"/"下移"/g' $APP_PATH/${APP}.el

sed -i 's/"Outline"/"大纲"/g' $APP_PATH/${APP}.el

#
sed -i 's/"Level 1."/"1级."/g' $APP_PATH/${APP}.el
sed -i 's/"Level 2."/"2级."/g' $APP_PATH/${APP}.el
sed -i 's/"Level 3."/"3级."/g' $APP_PATH/${APP}.el
sed -i 's/"Level 4."/"4级."/g' $APP_PATH/${APP}.el
sed -i 's/"Level 5."/"5级."/g' $APP_PATH/${APP}.el
sed -i 's/"Level 6."/"6级."/g' $APP_PATH/${APP}.el
sed -i 's/"Level 7."/"7级."/g' $APP_PATH/${APP}.el
sed -i 's/"Level 8."/"8级."/g' $APP_PATH/${APP}.el

sed -i 's/"before first heading"/"在第一个标题前面"/g' $APP_PATH/${APP}.el
sed -i 's/"Cannot move past superior level"/"无法移动超过超级层"/g' $APP_PATH/${APP}.el
sed -i 's/"Must keep at least one level of headers"/"必须至少保留标题(header)的某一级"/g' $APP_PATH/${APP}.el

sed -i 's/"Parent"/"上级"/g' $APP_PATH/${APP}.el
sed -i 's/"No following same-level heading"/"后面没有同级标题"/g' $APP_PATH/${APP}.el
sed -i 's/"No previous same-level heading"/"没有上一个同级标题"/g' $APP_PATH/${APP}.el

#sed -i 's/""/""/g' $APP_PATH/${APP}.el


### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."
cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el

## OPTIONAL MODULE
if [ $ENABLE_WIN_ICONV = "1" ];then
## for Emacs/Windows, some files such as
## lisp/international/mule-cmds.el
## lisp/language/chinese.el
## lisp/language/*.el
## calendar/lunar.el
## 
## and more any other files which may include non-ascii charactors should
## convert translated .el file to Windows UNICODE coding
## ( = utf-16le-with-signature in Emacs) to show local language text well,
## and never be utf-8, gbk/gb2312/gb18030 or any other codings..
## in some Emacs versions for Windows, utf-8 may works also ok, but for 
## simple and unify, we convert all to utf-16le-bom
	cd ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/
	iconv -f utf-8 -t UTF-16LE $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf-16le.el
	cat $FFFE $APP_PATH/${APP}_utf-16le.el > $APP_PATH/${APP}_utf-16le-bom.el  
	mv -fv $APP_PATH/${APP}_utf-16le-bom.el $APP_PATH/${APP}.el
## touch an empty file for remark	
	touch $APP_PATH/${APP}_utf-16le-with-signature.el
	rm -f $APP_PATH/${APP}_utf-16le.el
fi
## MODULE END	
## Emacs/Windows end

echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;
    
    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;
