#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='progmodes'
APP='python'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages. 

  -t, --translate VERSION LANGUAGE   
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate) 
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi
	
## mkdir for translated .el files to save, for linux 
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows 
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

#;;; python.el --- silly walks for Python  -*- coding: iso-8859-1 -*-
## iconv encoding from iso-8859-1 to utf-8 first, 
## or can't translate to other languages, or show in bad enconding

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el


#sed -i 's///g' $APP_PATH/${APP}.el

sed -i 's/^;;; python.el --- silly walks for Python  -\*- coding: iso-8859-1/;;; python.el --- silly walks for Python  -\*- coding: utf-8/g' $APP_PATH/${APP}.el

## for example:
#
sed -i 's/"Shift region left"/"区域向左位移"/g' $APP_PATH/${APP}.el
sed -i 's/"Shift region right"/"区域向右位移"/g' $APP_PATH/${APP}.el
sed -i 's/"Mark block"/"标记块"/g' $APP_PATH/${APP}.el
sed -i 's/"Mark def\/class"/"标记 def\/class"/g' $APP_PATH/${APP}.el
sed -i 's/"Start of block"/"块开始"/g' $APP_PATH/${APP}.el
sed -i 's/"End of block"/"块结束"/g' $APP_PATH/${APP}.el
sed -i 's/"Start of def\/class"/"def\/class 开始"/g' $APP_PATH/${APP}.el
sed -i 's/"End of def\/class"/"def\/class 结束"/g' $APP_PATH/${APP}.el

sed -i 's/"Templates..."/"模板..."/g' $APP_PATH/${APP}.el
sed -i 's/"Start interpreter"/"启动解释器"/g' $APP_PATH/${APP}.el
sed -i 's/"Import\/reload file"/"导入\/重新加载文件"/g' $APP_PATH/${APP}.el
sed -i 's/"Eval buffer"/"对缓冲区求值"/g' $APP_PATH/${APP}.el
sed -i 's/"Eval region"/"对区域求值"/g' $APP_PATH/${APP}.el
sed -i 's/"Eval def\/class"/"def\/class 求值"/g' $APP_PATH/${APP}.el
sed -i 's/"Switch to interpreter"/"切换到解释器"/g' $APP_PATH/${APP}.el
sed -i 's/"Set default process"/"设置默认进程"/g' $APP_PATH/${APP}.el

sed -i 's/"Check file"/"核对文件"/g' $APP_PATH/${APP}.el
sed -i 's/"Debugger"/"调试器"/g' $APP_PATH/${APP}.el
sed -i 's/"Help on symbol"/"显示符号帮助信息"/g' $APP_PATH/${APP}.el
sed -i 's/"Complete symbol"/"补齐符号"/g' $APP_PATH/${APP}.el

sed -i 's/"Find function"/"查找函数"/g' $APP_PATH/${APP}.el
sed -i 's/"Update imports"/"更新导入(imports)"/g' $APP_PATH/${APP}.el

#
sed -i 's/"Module variables"/"模块变量"/g' $APP_PATH/${APP}.el
sed -i 's/"Close %s"/"闭合 %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Run Python: "/"运行 Python: "/g' $APP_PATH/${APP}.el
sed -i 's/"Describe symbol (default %s): "/"描述符号(默认为 %s): "/g' $APP_PATH/${APP}.el
sed -i 's/"Describe symbol: "/"描述符: "/g' $APP_PATH/${APP}.el
sed -i 's/"No symbol"/"没有符号"/g' $APP_PATH/${APP}.el
sed -i 's/"Undefined template: %s"/"未定义的模板: %s"/g' $APP_PATH/${APP}.el

#
sed -i 's/"Bicycle Repair Man"/"自行车修理工"/g' $APP_PATH/${APP}.el
sed -i 's/"BicycleRepairMan"/"自行车修理工"/g' $APP_PATH/${APP}.el
sed -i 's/"Queries"/"查询"/g' $APP_PATH/${APP}.el
sed -i 's/"Find References"/"查找参考"/g' $APP_PATH/${APP}.el
sed -i 's/"Find Definition"/"查找定义"/g' $APP_PATH/${APP}.el

#,fuzzy
#sed -i 's/"Refactoring"/""/g' $APP_PATH/${APP}.el

sed -i 's/"Rename"/"重命名"/g' $APP_PATH/${APP}.el
sed -i 's/"Extract Method"/"展开方法"/g' $APP_PATH/${APP}.el
sed -i 's/"Extract Local Variable"/"展开本地变量"/g' $APP_PATH/${APP}.el
sed -i 's/"Inline Local Variable"/"联机本地变量"/g' $APP_PATH/${APP}.el

#,fuzzy
sed -i 's/"Undo Last Refactoring"/"撤消上次的 Refactoring"/g' $APP_PATH/${APP}.el

sed -i 's/"BicycleRepairMan setup failed: %s"/"自行车修理工设置失败: %s"/g' $APP_PATH/${APP}.el
sed -i 's/" arguments: "/" 参数: "/g' $APP_PATH/${APP}.el

# care with '
sed -i 's/"No process associated with buffer '\''%s'\''"/"没有与缓冲区 <%s> 相关的进程"/g' $APP_PATH/${APP}.el


### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."
cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el

## OPTIONAL MODULE
if [ $ENABLE_WIN_ICONV = "1" ];then
## for Emacs/Windows, some files such as
## lisp/international/mule-cmds.el
## lisp/language/chinese.el
## lisp/language/*.el
## calendar/lunar.el
## 
## and more any other files which may include non-ascii charactors should
## convert translated .el file to Windows UNICODE coding
## ( = utf-16le-with-signature in Emacs) to show local language text well,
## and never be utf-8, gbk/gb2312/gb18030 or any other codings..
## in some Emacs versions for Windows, utf-8 may works also ok, but for 
## simple and unify, we convert all to utf-16le-bom
	cd ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/
	iconv -f utf-8 -t UTF-16LE $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf-16le.el
	cat $FFFE $APP_PATH/${APP}_utf-16le.el > $APP_PATH/${APP}_utf-16le-bom.el  
	mv -fv $APP_PATH/${APP}_utf-16le-bom.el $APP_PATH/${APP}.el
## touch an empty file for remark	
	touch $APP_PATH/${APP}_utf-16le-with-signature.el
	rm -f $APP_PATH/${APP}_utf-16le.el
fi
## MODULE END	
## Emacs/Windows end

echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;
    
    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;
