#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='.'
APP='speedbar'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages. 

  -t, --translate VERSION LANGUAGE   
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate) 
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi
	
## mkdir for translated .el files to save, for linux 
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows 
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

#sed -i 's/""/""/g' $APP_PATH/${APP}.el

# never need to translate following 3 line, or show bad codings in Emacs/Windows
#sed -i 's/"buffers"/"缓冲区"/g' $APP_PATH/${APP}.el
#sed -i 's/"quick buffers"/"快速缓冲区"/g' $APP_PATH/${APP}.el
#sed -i 's/"files"/"文件"/g' $APP_PATH/${APP}.el
# Emacs/Windows END

sed -i 's/"Speedbar"/"快捷栏"/g' $APP_PATH/${APP}.el
sed -i 's/"Speedbar "/"快捷栏 "/g' $APP_PATH/${APP}.el
sed -i 's/" SPEEDBAR"/" 快捷栏"/g' $APP_PATH/${APP}.el

sed -i 's/"Update"/"更新"/g' $APP_PATH/${APP}.el
sed -i 's/"Auto Update"/"自动更新"/g' $APP_PATH/${APP}.el

sed -i 's/"Use Images"/"使用图像"/g' $APP_PATH/${APP}.el
sed -i 's/"Edit Item On Line"/"在线编辑条目"/g' $APP_PATH/${APP}.el
sed -i 's/"Show All Files"/"显示全部文件"/g' $APP_PATH/${APP}.el

sed -i 's/"Expand File Tags"/"展开文件 Tags 标识"/g' $APP_PATH/${APP}.el
sed -i 's/"Flush Cache & Expand"/"大量缓存和展开"/g' $APP_PATH/${APP}.el
sed -i 's/"Expand All Descendants"/"展开全部的折叠项"/g' $APP_PATH/${APP}.el

sed -i 's/"Contract File Tags"/"折叠文件 Tags 标识"/g' $APP_PATH/${APP}.el
sed -i 's/"File\/Tag Information"/"文件\/Tag 标识信息"/g' $APP_PATH/${APP}.el
sed -i 's/"Load Lisp File"/"加载 Lisp 文件"/g' $APP_PATH/${APP}.el

sed -i 's/"Byte Compile File"/"字节编译文件"/g' $APP_PATH/${APP}.el
sed -i 's/"Copy File"/"复制文件"/g' $APP_PATH/${APP}.el
sed -i 's/"Rename File"/"重命名文件"/g' $APP_PATH/${APP}.el

sed -i 's/"Create Directory"/"创建目录"/g' $APP_PATH/${APP}.el
sed -i 's/"Delete File"/"删除文件"/g' $APP_PATH/${APP}.el
sed -i 's/"Delete Object"/"删除对象"/g' $APP_PATH/${APP}.el

sed -i 's/"Customize..."/"自定义..."/g' $APP_PATH/${APP}.el
sed -i 's/"Close"/"关闭"/g' $APP_PATH/${APP}.el
sed -i 's/"Quit"/"退出"/g' $APP_PATH/${APP}.el

sed -i 's/"Displays"/"显示"/g' $APP_PATH/${APP}.el
sed -i 's/"Speedbar menu"/"快捷栏菜单"/g' $APP_PATH/${APP}.el

sed -i 's/"End of sub-list"/"已到子列表尾部"/g' $APP_PATH/${APP}.el
sed -i 's/"Refreshing speedbar..."/"刷新快捷栏..."/g' $APP_PATH/${APP}.el

sed -i 's/"Refreshing speedbar...done"/"刷新快捷栏...完成"/g' $APP_PATH/${APP}.el

#sed -i 's/"Load %sc? "/""/g' $APP_PATH/${APP}.el

sed -i 's/"Not a loadable file"/"不是可加载的文件"/g' $APP_PATH/${APP}.el
sed -i 's/"Text: %s"/"文本: %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Detail: %s of tag %s"/"详情: %s of tag %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Detail: %s"/"详情: %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Not a file"/"不是文件"/g' $APP_PATH/${APP}.el
sed -i 's/"Copy %s to: "/"复制 %s 到: "/g' $APP_PATH/${APP}.el
sed -i 's/"Overwrite %s with %s? "/"覆盖 %s (用 %s)? "/g' $APP_PATH/${APP}.el
sed -i 's/"Rename %s to: "/"重命名 %s 为: "/g' $APP_PATH/${APP}.el
sed -i 's/"Create directory: "/"创建目录: "/g' $APP_PATH/${APP}.el
sed -i 's/"Delete %s? "/"删除 %s? "/g' $APP_PATH/${APP}.el

# ,fuzzy
sed -i 's/"Okie dokie."/"确认执行."/g' $APP_PATH/${APP}.el

sed -i 's/"Speedbar Mode (default %s): "/"快捷栏模式(默认为 %s): "/g' $APP_PATH/${APP}.el
sed -i 's/"Tags"/"Tags标识"/g' $APP_PATH/${APP}.el

#sed -i 's/"\*Rescan\*"/"\*重新扫描\*"/g' $APP_PATH/${APP}.el

sed -i 's/"Updating speedbar to: %s..."/"更新快捷栏到: %s..."/g' $APP_PATH/${APP}.el
sed -i 's/"Updating speedbar to: %s...done"/"更新快捷栏到: %s...完成"/g' $APP_PATH/${APP}.el
sed -i 's/"Updating speedbar to special mode: %s..."/"更新快捷栏到指定模式: %s..."/g' $APP_PATH/${APP}.el
sed -i 's/"Updating speedbar to special mode: %s...done"/"更新快捷栏到指定模式: %s...完成"/g' $APP_PATH/${APP}.el
sed -i 's/"Go to the line where FILE is."/"转到指定文件所在的行."/g' $APP_PATH/${APP}.el
sed -i 's/"Speedbar vc check...%s"/"快捷栏版本控制检查...%s"/g' $APP_PATH/${APP}.el
sed -i 's/"Error building filename of tag"/"建立 tag 标识的文件名时出错"/g' $APP_PATH/${APP}.el
sed -i 's/"Internal Error: File %s not shown in speedbar"/"内部错误: 文件 %s 在快捷栏中未显示"/g' $APP_PATH/${APP}.el
sed -i 's/"Ooops...  not sure what to do"/"等等... 不能明确要干什么"/g' $APP_PATH/${APP}.el

# ,fuzzy
#sed -i 's/"\*etags tmp\*"/"\*临时 etags 标识\*"/g' $APP_PATH/${APP}.el

sed -i 's/"Fetching etags..."/"获取 etags 标识..."/g' $APP_PATH/${APP}.el
sed -i 's/"Jump to buffer"/"跳转到缓冲区"/g' $APP_PATH/${APP}.el

sed -i 's/"Kill Buffer"/"剪切(杀死)缓冲区"/g' $APP_PATH/${APP}.el
sed -i 's/"Revert Buffer"/"重读缓冲区"/g' $APP_PATH/${APP}.el
sed -i 's/"Scratch Buffers:"/"草稿缓冲区:"/g' $APP_PATH/${APP}.el
sed -i 's/"<No file>"/"<无文件>"/g' $APP_PATH/${APP}.el
sed -i 's/"Kill buffer %s? "/"剪切(杀死)缓冲区 %s? "/g' $APP_PATH/${APP}.el

#
sed -i 's/"Speedbar face for +\/- buttons."/"+\/- 按钮的快捷栏外观."/g' $APP_PATH/${APP}.el
sed -i 's/"Speedbar face for file names."/"文件名的快捷栏外观."/g' $APP_PATH/${APP}.el
sed -i 's/"Speedbar face for directory names."/"目录名的快捷栏外观."/g' $APP_PATH/${APP}.el
sed -i 's/"Speedbar face for tags."/"tags 标识的快捷栏外观."/g' $APP_PATH/${APP}.el
sed -i 's/"Speedbar face for the file in the active window."/"活动窗格中的文件的快捷栏外观."/g' $APP_PATH/${APP}.el
sed -i 's/"Speedbar face for highlighting buttons with the mouse."/"鼠标按钮高亮的快捷栏外观."/g' $APP_PATH/${APP}.el
sed -i 's/"Speedbar face for separator labels in a display."/"显示区分隔条标签的快捷栏外观."/g' $APP_PATH/${APP}.el
#sed -i 's/"Mode"/"模式"/g' $APP_PATH/${APP}.el
#sed -i 's/""/""/g' $APP_PATH/${APP}.el


### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."
cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/	
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;
    
    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;

