#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='textmodes'
APP='ispell'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages. 

  -t, --translate VERSION LANGUAGE   
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate) 
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi
	
## mkdir for translated .el files to save, for linux 
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows 
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

## for example:
#sed -i 's/""/""/g' $APP_PATH/${APP}.el
sed -i 's/"Help"/"帮助"/g' $APP_PATH/${APP}.el
sed -i 's/"Check Message"/"检查信息"/g' $APP_PATH/${APP}.el
sed -i 's/"Check Buffer"/"检查缓冲区"/g' $APP_PATH/${APP}.el
sed -i 's/"Check Comments"/"检查注释"/g' $APP_PATH/${APP}.el
sed -i 's/"Check Word"/"检查单词"/g' $APP_PATH/${APP}.el
sed -i 's/"Check Region"/"检查区域"/g' $APP_PATH/${APP}.el
sed -i 's/"Continue Check"/"继续检查"/g' $APP_PATH/${APP}.el
sed -i 's/"Complete Word Frag"/"补齐拆分的单词"/g' $APP_PATH/${APP}.el
sed -i 's/"Complete Word"/"补齐单词"/g' $APP_PATH/${APP}.el
sed -i 's/"Kill Process"/"杀死进程"/g' $APP_PATH/${APP}.el
sed -i 's/"Customize..."/"自定义..."/g' $APP_PATH/${APP}.el
sed -i 's/"Save Personal Dict"/"保存个人字典"/g' $APP_PATH/${APP}.el
sed -i 's/"Change Dictionary"/"更改字典"/g' $APP_PATH/${APP}.el
# for 23.1
sed -i 's/"Spell-Check Message"/"对信息进行拼写检查"/g' $APP_PATH/${APP}.el
sed -i 's/"Spell-Check Buffer"/"对缓冲区进行拼写检查"/g' $APP_PATH/${APP}.el
sed -i 's/"Spell-Check Comments"/"对注释进行拼写检查"/g' $APP_PATH/${APP}.el
sed -i 's/"Spell-Check Word"/"对单词进行拼写检查"/g' $APP_PATH/${APP}.el
sed -i 's/"Spell-Check Region"/"对区域进行拼写检查"/g' $APP_PATH/${APP}.el
sed -i 's/"Continue Spell-Checking"/"继续拼写检查"/g' $APP_PATH/${APP}.el
sed -i 's/"Complete Word Fragment"/"补齐拆分的单词"/g' $APP_PATH/${APP}.el

sed -i 's/"Automatic spell checking (Flyspell)"/"自动拼写检查 (Flyspell)"/g' $APP_PATH/${APP}.el

sed -i 's/"Save Dictionary"/"保存字典"/g' $APP_PATH/${APP}.el
sed -i 's/"Change Dictionary..."/"更改字典..."/g' $APP_PATH/${APP}.el
# 23.1 end
sed -i 's/"Cmds"/"命令"/g' $APP_PATH/${APP}.el
sed -i 's/"Spell-Check"/"拼写检查"/g' $APP_PATH/${APP}.el
sed -i 's/"Edit"/"编辑"/g' $APP_PATH/${APP}.el
sed -i 's/"Spell"/"拼写"/g' $APP_PATH/${APP}.el
sed -i 's/"Dictionary"/"字典"/g' $APP_PATH/${APP}.el

sed -i 's/"Dictionary name"/"字典名称"/g' $APP_PATH/${APP}.el
#sed -i 's/"default"/""/g' $APP_PATH/${APP}.el
sed -i 's/"Case characters"/"区分字母大小写"/g' $APP_PATH/${APP}.el
sed -i 's/"Non case characters"/"不区分字母大小写"/g' $APP_PATH/${APP}.el
sed -i 's/"Other characters"/"其它字符"/g' $APP_PATH/${APP}.el
sed -i 's/"Many other characters"/"很多其它字符"/g' $APP_PATH/${APP}.el
sed -i 's/"Ispell command line args"/"Ispell 命令行参数"/g' $APP_PATH/${APP}.el
sed -i 's/"Extended character mode"/"扩展字符模式"/g' $APP_PATH/${APP}.el
sed -i 's/"Coding System"/"文字编码"/g' $APP_PATH/${APP}.el

### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."
cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/	
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el

echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;
    
    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;
