#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='textmodes'
APP='sgml-mode'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages. 

  -t, --translate VERSION LANGUAGE   
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate) 
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi
	
## mkdir for translated .el files to save, for linux 
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows 
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

#;;; sgml-mode.el --- SGML- and HTML-editing modes -*- coding: iso-2022-7bit -*-
## iconv encoding from iso-2022-7bit (= ISO-2022-CN) to utf-8 first, 
## or can't translate to other languages, or show in bad enconding

#
#mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

#sed -i 's/^;;; sgml-mode.el --- SGML- and HTML-editing modes -\*- coding: iso-2022-7bit/;;; sgml-mode.el --- SGML- and HTML-editing modes -\*- coding: utf-8/g' $APP_PATH/${APP}.el

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

iconv -f ISO-2022-CN -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

## for example:
#
sed -i 's/"Validate"/"有效的"/g' $APP_PATH/${APP}.el
sed -i 's/"Toggle 8 Bit Insertion"/"切换8位插入"/g' $APP_PATH/${APP}.el
sed -i 's/"Toggle Tag Visibility"/"切换 Tag 标识可见性"/g' $APP_PATH/${APP}.el
sed -i 's/"Describe Tag"/"描述 Tag 标识"/g' $APP_PATH/${APP}.el
sed -i 's/"Delete Tag"/"删除 Tag 标识"/g' $APP_PATH/${APP}.el
sed -i 's/"Forward Tag"/"下面的 Tag 标识"/g' $APP_PATH/${APP}.el
sed -i 's/"Backward Tag"/"上面的 Tag 标识"/g' $APP_PATH/${APP}.el
sed -i 's/"Insert Attributes"/"插入属性"/g' $APP_PATH/${APP}.el
sed -i 's/"Insert Tag"/"插入 Tag 标识"/g' $APP_PATH/${APP}.el

sed -i 's/"Matches %s"/"匹配 %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Enter char or octal number"/"输入字符或八进制数字"/g' $APP_PATH/${APP}.el
sed -i 's/"No char before point"/"位置前面没有字符"/g' $APP_PATH/${APP}.el

# care with ' 
sed -i 's/"Don'\''t know the name of `%c'\''"/"不知道 %c 的名称"/g' $APP_PATH/${APP}.el

sed -i 's/"Tag (default %s): "/"Tag 标识(默认为 %s): "/g' $APP_PATH/${APP}.el
sed -i 's/"Attribute: "/"属性: "/g' $APP_PATH/${APP}.el
sed -i 's/"No tag selected"/"未选择 tag 标识"/g' $APP_PATH/${APP}.el
sed -i 's/"No description available"/"没有可用的描述"/g' $APP_PATH/${APP}.el
sed -i 's/"sgml-electric-tag-pair-before-change-function: deleting old OLs"/""sgml-electric-tag-pair-before-change-function: 删除旧的 OL/g' $APP_PATH/${APP}.el
sed -i 's/"sgml-electric-tag-pair-before-change-function: new clone"/"sgml-electric-tag-pair-before-change-function: 新建克隆"/g' $APP_PATH/${APP}.el
sed -i 's/"Error in sgml-electric-pair-mode: %s"/"sgml-electric-pair-mode 错误: %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Invisible tag: %s"/"不可见 tag 标识: %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Validate command: "/"可用的命令: "/g' $APP_PATH/${APP}.el
sed -i 's/"No tag found"/"未找到 tag 标识"/g' $APP_PATH/${APP}.el
sed -i 's/"Unclosed tag <%s>"/"未闭合的 tag 标识 <%s>"/g' $APP_PATH/${APP}.el

# care with / 
sed -i 's/"Unmatched tags <%s> and <\/%s>"/"不配对的 tag 标识 <%s> 和 <\/%s>"/g' $APP_PATH/${APP}.el
sed -i 's/"Spurious <\/%s>: empty tag"/"意外的 <\/%s>: 空白的 tag 标识"/g' $APP_PATH/${APP}.el

#,fuzzy
#sed -i 's/"*XML Context*"/"\*XML 文本\*"/g' $APP_PATH/${APP}.el

sed -i 's/"Nothing to close"/"没有什么需要闭合的"/g' $APP_PATH/${APP}.el
sed -i 's/"Unrecognized context %s"/"不可识别的文本 %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Guessed sgml-basic-offset = %d"/"推测 sgml-basic-offset = %d"/g' $APP_PATH/${APP}.el

#,fuzzy
sed -i 's/"EMPTY"/"空"/g' $APP_PATH/${APP}.el

#
sed -i 's/"Heading 6"/"6级标题 <h6>"/g' $APP_PATH/${APP}.el
sed -i 's/"Heading 5"/"5级标题 <h5>"/g' $APP_PATH/${APP}.el
sed -i 's/"Heading 4"/"4级标题 <h4>"/g' $APP_PATH/${APP}.el
sed -i 's/"Heading 3"/"3级标题 <h3>"/g' $APP_PATH/${APP}.el
sed -i 's/"Heading 2"/"2级标题 <h2>"/g' $APP_PATH/${APP}.el
sed -i 's/"Heading 1"/"1级标题 <h1>"/g' $APP_PATH/${APP}.el
sed -i 's/"Radio Buttons"/"单选按钮 <input radio>"/g' $APP_PATH/${APP}.el
sed -i 's/"Checkboxes"/"复选框 <input checkbox>"/g' $APP_PATH/${APP}.el
sed -i 's/"List Item"/"列表项 <li>"/g' $APP_PATH/${APP}.el
sed -i 's/"Unordered List"/"无序列表 <ul>"/g' $APP_PATH/${APP}.el
sed -i 's/"Ordered List"/"有序列表 <ol>"/g' $APP_PATH/${APP}.el
sed -i 's/"Horizontal Rule"/"水平线 <hr>"/g' $APP_PATH/${APP}.el
sed -i 's/"Line Break"/"断行 <br>"/g' $APP_PATH/${APP}.el
sed -i 's/"Paragraph"/"段落 <p>"/g' $APP_PATH/${APP}.el
sed -i 's/"Image"/"图像 <img>"/g' $APP_PATH/${APP}.el
sed -i 's/"Href Anchor"/"超链接锚 <a href>"/g' $APP_PATH/${APP}.el
sed -i 's/"Name Anchor"/"名称锚 <a name>"/g' $APP_PATH/${APP}.el

#
#sed -i 's/""/""/g' $APP_PATH/${APP}.el

#sed -i 's/"Bold face"/"粗体"/g' $APP_PATH/${APP}.el


### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."
cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el

## OPTIONAL MODULE
if [ $ENABLE_WIN_ICONV = "1" ];then
## for Emacs/Windows, some files such as
## lisp/international/mule-cmds.el
## lisp/language/chinese.el
## lisp/language/*.el
## calendar/lunar.el
## 
## and more any other files which may include non-ascii charactors should
## convert translated .el file to Windows UNICODE coding
## ( = utf-16le-with-signature in Emacs) to show local language text well,
## and never be utf-8, gbk/gb2312/gb18030 or any other codings..
## in some Emacs versions for Windows, utf-8 may works also ok, but for 
## simple and unify, we convert all to utf-16le-bom
	cd ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/
	iconv -f utf-8 -t UTF-16LE $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf-16le.el
	cat $FFFE $APP_PATH/${APP}_utf-16le.el > $APP_PATH/${APP}_utf-16le-bom.el  
	mv -fv $APP_PATH/${APP}_utf-16le-bom.el $APP_PATH/${APP}.el
## touch an empty file for remark	
	touch $APP_PATH/${APP}_utf-16le-with-signature.el
	rm -f $APP_PATH/${APP}_utf-16le.el
fi
## MODULE END	
## Emacs/Windows end

echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;
    
    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;
