#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='.'
APP='time'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages. 

  -t, --translate VERSION LANGUAGE   
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate) 
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi

## mkdir for translated .el files to save, for linux 
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows 
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

## for example:
#sed -i 's/""/""/g' $APP_PATH/${APP}.el
sed -i 's/"None"/"无"/g' $APP_PATH/${APP}.el
sed -i 's/"America\/Los_Angeles"/"美国\/洛杉矶"/g' $APP_PATH/${APP}.el
sed -i 's/"Seattle"/"西雅图"/g' $APP_PATH/${APP}.el
sed -i 's/"America\/New_York"/"美国\/纽约"/g' $APP_PATH/${APP}.el
# another string in some other version
sed -i 's/"America\/New York"/"美国\/纽约"/g' $APP_PATH/${APP}.el
sed -i 's/"America\/Los Angeles"/"美国\/洛杉矶"/g' $APP_PATH/${APP}.el
# another end
sed -i 's/"New York"/"纽约"/g' $APP_PATH/${APP}.el
sed -i 's/"Europe\/London"/"欧洲\/伦敦"/g' $APP_PATH/${APP}.el
sed -i 's/"London"/"伦敦"/g' $APP_PATH/${APP}.el
sed -i 's/"Europe\/Paris"/"欧洲\/巴黎"/g' $APP_PATH/${APP}.el
sed -i 's/"Paris"/"巴黎"/g' $APP_PATH/${APP}.el
sed -i 's/"Asia\/Calcutta"/"亚洲\/加尔各答"/g' $APP_PATH/${APP}.el
sed -i 's/"Bangalore"/"班加罗尔"/g' $APP_PATH/${APP}.el
sed -i 's/"Asia\/Tokyo"/"亚洲\/东京"/g' $APP_PATH/${APP}.el
sed -i 's/"Tokyo"/"东京"/g' $APP_PATH/${APP}.el
sed -i 's/"Default"/"默认"/g' $APP_PATH/${APP}.el
sed -i 's/"1 minute load"/"1分钟负载"/g' $APP_PATH/${APP}.el
sed -i 's/"5 minutes load"/"5分钟负载"/g' $APP_PATH/${APP}.el
sed -i 's/"15 minutes load"/"15分钟负载"/g' $APP_PATH/${APP}.el
sed -i 's/"\*wclock\*"/"\*世界时钟\*"/g' $APP_PATH/${APP}.el
sed -i 's/"Mail"/"邮件"/g' $APP_PATH/${APP}.el
sed -i 's/"Unicode letter character"/"Unicode 信件符号"/g' $APP_PATH/${APP}.el
sed -i 's/"1 minute"/"1分钟"/g' $APP_PATH/${APP}.el
sed -i 's/"5 minutes"/"5分钟"/g' $APP_PATH/${APP}.el
sed -i 's/"15 minutes"/"15分钟"/g' $APP_PATH/${APP}.el

# keep orig English string for devar, not need to translate
#sed -i 's/"MAIL"/"邮件"/g' $APP_PATH/${APP}.el
sed -i 's/"%.1f seconds"/"%.1f秒"/g' $APP_PATH/${APP}.el
#
sed -i 's/"Jan"/"一月"/g' $APP_PATH/${APP}.el
sed -i 's/"Feb"/"二月"/g' $APP_PATH/${APP}.el
sed -i 's/"Mar"/"三月"/g' $APP_PATH/${APP}.el
sed -i 's/"Apr"/"四月"/g' $APP_PATH/${APP}.el
sed -i 's/"May"/"五月"/g' $APP_PATH/${APP}.el
sed -i 's/"Jun"/"六月"/g' $APP_PATH/${APP}.el
sed -i 's/"Jul"/"七月"/g' $APP_PATH/${APP}.el
sed -i 's/"Aug"/"八月"/g' $APP_PATH/${APP}.el
sed -i 's/"Sep"/"九月"/g' $APP_PATH/${APP}.el
sed -i 's/"Oct"/"十月"/g' $APP_PATH/${APP}.el
#
#sed -i 's/"Nov"/"十一月"/g' $APP_PATH/${APP}.el
#sed -i 's/"Dec"/"十二月"/g' $APP_PATH/${APP}.el
# 十一月 = 冬月；十二月 = 腊月;
sed -i 's/"Nov"/"冬月"/g' $APP_PATH/${APP}.el
sed -i 's/"Dec"/"腊月"/g' $APP_PATH/${APP}.el
#

### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."
cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el

echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;
    
    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;
