#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130127
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='vc'
APP='ediff-hook'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages. 

  -t, --translate VERSION LANGUAGE   
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate) 
if [ $# -lt 3 ]; then
    echo "Error: bad arguments or arguments not enough."
    echo "example: $0 -t 24.1 zh_CN"
    exit 1 ;
fi

echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi

## mkdir for translated .el files to save, for linux 
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows 
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

## for example:
#sed -i 's/""/""/g' $APP_PATH/${APP}.el
sed -i 's/"Apply Patch"/"应用补丁"/g' $APP_PATH/${APP}.el
sed -i 's/"Ediff Miscellanea"/"Ediff 杂项"/g' $APP_PATH/${APP}.el
sed -i 's/"Tools"/"工具"/g' $APP_PATH/${APP}.el

sed -i 's/"Merge"/"合并"/g' $APP_PATH/${APP}.el
sed -i 's/"OO-Browser..."/"OO-浏览..."/g' $APP_PATH/${APP}.el
sed -i 's/"Compare"/"比对"/g' $APP_PATH/${APP}.el
sed -i 's/"Two Files..."/"两个文件..."/g' $APP_PATH/${APP}.el
sed -i 's/"Two Buffers..."/"两个缓冲区..."/g' $APP_PATH/${APP}.el
sed -i 's/"Two Directories..."/"两个目录..."/g' $APP_PATH/${APP}.el
sed -i 's/"Three Files..."/"三个文件..."/g' $APP_PATH/${APP}.el
sed -i 's/"Three Buffers..."/"三个缓冲区..."/g' $APP_PATH/${APP}.el
sed -i 's/"Three Directories..."/"三个目录..."/g' $APP_PATH/${APP}.el
sed -i 's/"File with Revision..."/"带修订版本的文件..."/g' $APP_PATH/${APP}.el
sed -i 's/"Directory Revisions..."/"目录修订版本..."/g' $APP_PATH/${APP}.el
sed -i 's/"Windows Word-by-word..."/"窗格字对字..."/g' $APP_PATH/${APP}.el
sed -i 's/"Windows Line-by-line..."/"窗格行对行..."/g' $APP_PATH/${APP}.el
sed -i 's/"Regions Word-by-word..."/"区域字对字..."/g' $APP_PATH/${APP}.el
sed -i 's/"Regions Line-by-line..."/"区域行对行..."/g' $APP_PATH/${APP}.el
#
sed -i 's/"Files..."/"文件..."/g' $APP_PATH/${APP}.el
sed -i 's/"Files with Ancestor..."/"带补丁包的文件..."/g' $APP_PATH/${APP}.el
sed -i 's/"Buffers..."/"缓冲区..."/g' $APP_PATH/${APP}.el
sed -i 's/"Buffers with Ancestor..."/"带补丁包的缓冲区..."/g' $APP_PATH/${APP}.el
sed -i 's/"Directories..."/"目录..."/g' $APP_PATH/${APP}.el
sed -i 's/"Directories with Ancestor..."/"带补丁包的目录..."/g' $APP_PATH/${APP}.el
sed -i 's/"Revisions..."/"修订版本..."/g' $APP_PATH/${APP}.el
sed -i 's/"Revisions with Ancestor..."/"带补丁包的修订版本..."/g' $APP_PATH/${APP}.el
sed -i 's/"Directory Revisions..."/"目录修订版本..."/g' $APP_PATH/${APP}.el
sed -i 's/"Directory Revisions with Ancestor..."/"带补丁包的目录修订版本..."/g' $APP_PATH/${APP}.el
#
sed -i 's/"Ediff Manual"/"Ediff 手册"/g' $APP_PATH/${APP}.el
sed -i 's/"Customize Ediff"/"自定义 Ediff"/g' $APP_PATH/${APP}.el
sed -i 's/"List Ediff Sessions"/"列出 Ediff 会话"/g' $APP_PATH/${APP}.el
sed -i 's/"Use separate frame for Ediff control buffer"/"为 Ediff 缓冲控制区使用分离的框架"/g' $APP_PATH/${APP}.el

# for 22.3
sed -i 's/"Use separate control buffer frame"/"使用单独控制的缓冲区架"/g' $APP_PATH/${APP}.el

sed -i 's/"Use a toolbar with Ediff control buffer"/"使用带 Ediff 缓冲控制区的工具栏"/g' $APP_PATH/${APP}.el
#
sed -i 's/"This Window and Next Window"/"当前和下一个窗格"/g' $APP_PATH/${APP}.el
#
sed -i 's/"To a Buffer..."/"到缓冲区..."/g' $APP_PATH/${APP}.el
sed -i 's/"To a File..."/"到文件..."/g' $APP_PATH/${APP}.el
#
sed -i 's/"To a buffer..."/"到缓冲区..."/g' $APP_PATH/${APP}.el
sed -i 's/"To a file..."/"到文件..."/g' $APP_PATH/${APP}.el
#
sed -i 's/"Apply a patch to a file"/"对文件打补丁"/g' $APP_PATH/${APP}.el
sed -i 's/"Toggle use of separate control buffer frame"/"切换分离式缓冲控制区框架"/g' $APP_PATH/${APP}.el

### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."
cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/	
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el

echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;
    
    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;
