#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='.'
APP='bookmark'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages. 

  -t, --translate VERSION LANGUAGE   
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate) 
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi
	
## mkdir for translated .el files to save, for linux 
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows 
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

#iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

## for example:
#sed -i 's/"Align"/"对齐"/g' $APP_PATH/${APP}.el

sed -i 's/"Bookmark functions"/"书签功能"/g' $APP_PATH/${APP}.el
sed -i 's/"Load a Bookmark File..."/"加载书签文件..."/g' $APP_PATH/${APP}.el
sed -i 's/"Save Bookmarks As..."/"书签另存为..."/g' $APP_PATH/${APP}.el

sed -i 's/"Save Bookmarks"/"保存书签"/g' $APP_PATH/${APP}.el
sed -i 's/"Edit Bookmark List"/"编辑书签列表"/g' $APP_PATH/${APP}.el
sed -i 's/"Delete Bookmark..."/"删除书签..."/g' $APP_PATH/${APP}.el
sed -i 's/"Rename Bookmark..."/"重命名书签..."/g' $APP_PATH/${APP}.el
sed -i 's/"Insert Location..."/"插入位置..."/g' $APP_PATH/${APP}.el
sed -i 's/"Insert Contents..."/"插入内容..."/g' $APP_PATH/${APP}.el
sed -i 's/"Set Bookmark..."/"设置书签..."/g' $APP_PATH/${APP}.el
sed -i 's/"Jump to Bookmark..."/"跳转到书签..."/g' $APP_PATH/${APP}.el
sed -i 's/"Deleting bookmarks...done"/"删除书签...完成"/g' $APP_PATH/${APP}.el
sed -i 's/"Deleting bookmarks..."/"删除书签..."/g' $APP_PATH/${APP}.el
sed -i 's/"Delete bookmarks flagged `D'\''."/"删除已标定为 D 的书签."/g' $APP_PATH/${APP}.el
sed -i 's/"\*Bookmark Annotation\*"/"\*书签注释\*"/g' $APP_PATH/${APP}.el
sed -i 's/"Set bookmark (%s): "/"设置书签 (%s): "/g' $APP_PATH/${APP}.el

sed -i 's/"Invalid bookmark %s"/"无效的书签 %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Not bookmark format"/"不是书签格式"/g' $APP_PATH/${APP}.el
sed -i 's/"Bookmark file format version strangeness"/"书签文件格式版本异常"/g' $APP_PATH/${APP}.el
sed -i 's/"Not in bookmark-edit-annotation-mode"/"未进入 bookmark-edit-annotation-mode 模式"/g' $APP_PATH/${APP}.el
sed -i 's/"Buffer not visiting a file or directory"/"缓冲区访问的不是一个文件或目录"/g' $APP_PATH/${APP}.el
sed -i 's/"No bookmark specified"/"未指定书签"/g' $APP_PATH/${APP}.el
sed -i 's/"Jumping to bookmark"/"跳转到书签"/g' $APP_PATH/${APP}.el
sed -i 's/"No such file or directory"/"没有这个文件或目录"/g' $APP_PATH/${APP}.el
sed -i 's/" nonexistent.  Relocate \"/" 不存在。重新定位 \"/g' $APP_PATH/${APP}.el
sed -i 's/"Bookmark not relocated; consider removing it \(%s\)."/"书签未找到；建议移除书签 \(%s\)。"/g' $APP_PATH/${APP}.el

sed -i 's/"File to save bookmarks in:"/"保存书签到文件:"/g' $APP_PATH/${APP}.el
sed -i 's/"Saving bookmarks to file %s..."/"保存书签到文件..."/g' $APP_PATH/${APP}.el
sed -i 's/"Can'\''t write %s"/"无法写入到 %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Saving bookmarks to file %s...done"/"保存书签到文件 %s...完成"/g' $APP_PATH/${APP}.el
sed -i 's/"Load bookmarks from: (%s) "/"从 %s 加载书签"/g' $APP_PATH/${APP}.el
sed -i 's/"Cannot read bookmark file %s"/"无法读取书签文件 %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Loading bookmarks from %s..."/"从 %s 加载书签..."/g' $APP_PATH/${APP}.el
sed -i 's/"Invalid bookmark list in %s"/"%s 的书签列表无效"/g' $APP_PATH/${APP}.el
sed -i 's/"Loading bookmarks from %s...done"/"从 %s 加载书签...完成"/g' $APP_PATH/${APP}.el
sed -i 's/"Unload the Bookmark library."/"取消加载书签库。"/g' $APP_PATH/${APP}.el
#
sed -i 's/"Bookmark"/"书签"/g' $APP_PATH/${APP}.el
sed -i 's/"Bookmarks"/"书签"/g' $APP_PATH/${APP}.el
# care with star * and space
sed -i 's/"\*Bookmarks\*"/"\*书签\*"/g' $APP_PATH/${APP}.el
# original string includes one space
sed -i 's/"\*Bookmark\*"/"\*书签\*"/g' $APP_PATH/${APP}.el

sed -i 's/" \*Bookmarks\*"/" \*书签\*"/g' $APP_PATH/${APP}.el
#
sed -i 's/"\*Bookmark List\*"/"\*书签列表\*"/g' $APP_PATH/${APP}.el

sed -i 's/"\*Bookmark Annotation Compose\*"/"\*书签注释书写\*"/g' $APP_PATH/${APP}.el

## care with \n 
sed -i 's/"\% Bookmark\\n- --------\\n"/"\% 书签\\n- --------\\n"/g' $APP_PATH/${APP}.el

#sed -i 's/""/""/g' $APP_PATH/${APP}.el

### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."
cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;
    
    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;

