#! /bin/sh -e
### ;;; * utf-8 *
## usage:
## 		 COMMAND -t VERSION LANGUAGE
## 	=	 COMMAND -t $2 $3
## EXAMPLE : 	#COMMAND -t 24.1 zh_CN
## -t = --translate
## updated by Careone <careone@wo.com.cn>, 20130115
## HEAD
EMACS_LOCALE_PATH='/usr/local/share/careone/emacs-locale'
EMACS_LOCALE_DEV_PATH='/usr/local/share/careone/emacs-locale-dev'
VERSION='15.0'
#TRANSED_PATH='~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/*.el'
TRANSOR_SIGN_FILE='emacs-transor-sign'
FFFE='/usr/local/share/careone/emacs-locale-dev/utf-16le-bom-fffe'
#
NAME_UPPER='Emacs'
NAME_LOWER='emacs'

# SWITCHES/OPTIONAL MODULE
ENABLE_WIN_ICONV='0'
ENABLE_WIN_REPLACE='0'
ENABLE_UNIX_REPLACE='0'
SHOW_TRANSED='0'

## APP_VER=$2
## APP_LANG=$3
APP_PATH='net'
APP='eudc'
## example: 	APP_PATH='play'
##  	    	APP='animate'
## means: 	lisp/play/animate.el
#
## HEAD END

### directories of Emacs lisp/*/ ###
# calc/
# calendar/
# emacs-lisp/
# emulation/
# erc/
# eshell/
# gnus/
# international/
# language/
# mail/
# mh-e/
# net/
# nxml/
# obsolete/
# org/
# play/
# progmodes/
# term/
# textmodes/
# url/
### directories end ###

###
# Usage: usage
# Print the usage.
usage () {
    cat <<EOF
Usage: $0 -t VERSION LANGUAGE
example: $0 -t 24.1 zh_CN

translate $NAME_UPPER lisp/*/*.el files to other languages. 

  -t, --translate VERSION LANGUAGE   
  		   translate $NAME_UPPER lisp/*/*.el files of special version
  -v, --version    print the version information and exit
  -h, --help       print this message and exit

Please report bugs to Careone <careone@wo.com.cn>.
EOF
}

# Check the arguments.
for option in "$@"; do
    case "$option" in
    -t | --translate) 
echo "*** translate ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el and save to"
echo -n "  ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ..."

## check and copy .el source files for translating, and
## if $2 (=VERSION) or $3 (=LANGAUGE) input error, or no avaid bin/ path, quit
	if ! [ -d ~/${NAME_LOWER}-$2/lisp/ ];then
		echo "~/${NAME_LOWER}-$2/lisp/ not found and nothing to do, quit."
		exit 1;
		elif ! [ -d $EMACS_LOCALE_PATH/$3/bin/ ];then
		echo "$EMACS_LOCALE_PATH/$3/bin/ not found and nothing to do, quit."
		exit 1;
	fi

## mkdir for translated .el files to save, for linux 
## path: ~/emacs-locale/usr/share/emacs/VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/ ];then
	mkdir -p ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/
fi

## mkdir for translated .el files to save, for windows 
## path: ~/emacs-locale/windows/emacs-VER/site-lisp/LANG/lisp/*/
if ! [ -d ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/ ];then
    mkdir -p ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/
fi

## check for .el source file and save to another one for translating
if [ -e ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	elif [ -e ~/${NAME_LOWER}-$2/lisp/${APP}.el ];then
	cp -p ~/${NAME_LOWER}-$2/lisp/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
	else echo "file not found, skip."
	exit 1;
fi

cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/

#;; Maintainer: Pavel Jan韐 <Pavel@Janik.cz>

## iconv and mark encoding from ? to utf-8 first, 
## or can't translate to other languages, or show in bad enconding
if [ -e $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE ]; then
cat $EMACS_LOCALE_DEV_PATH/$3/$TRANSOR_SIGN_FILE > emacs-transor-sign.$3
else echo -n ";;; ($3) localization resources for Emacs. " > emacs-transor-sign.$3
fi
echo ";;; -*- coding: utf-8 -*-" >> emacs-transor-sign.$3
echo ";;; translate script version $VERSION, $(date +"%Y-%m-%d %H:%M:%S %Z") translated" >> emacs-transor-sign.$3

iconv -f ISO-8859-1 -t UTF-8 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el

## must iconv to utf-8 first (is needed) before add sign in head, because if
## your sign file include non-ascii charactors may cause strange encodings 
## mixed
cat emacs-transor-sign.$3 $APP_PATH/${APP}.el > $APP_PATH/${APP}_utf8.el
mv -f $APP_PATH/${APP}_utf8.el $APP_PATH/${APP}.el

#sed -i 's///g' $APP_PATH/${APP}.el

#sed -i 's/""/""/g' $APP_PATH/${APP}.el
sed -i 's/"Malformed plist"/"plist 列表异常"/g' $APP_PATH/${APP}.el
sed -i 's/"Protocol"/"协议"/g' $APP_PATH/${APP}.el
sed -i 's/"Multiple matches found; choose one: "/"找到多个匹配结果；选择一个: "/g' $APP_PATH/${APP}.el
sed -i 's/"Don'\''t know how to perform the query"/"不知道如何进行查询"/g' $APP_PATH/${APP}.el
sed -i 's/"\*Directory Query Results\*"/"\*目录查询结果\*"/g' $APP_PATH/${APP}.el

# care with \n (2 letters), show write to \\n (3 letters)
sed -i 's/"Directory Query Result\\n"/"目录查询结果\\n"/g' $APP_PATH/${APP}.el
#
sed -i 's/"No match found.\\n"/"未找到符合的。\\n"/g' $APP_PATH/${APP}.el

#sed -i 's/"Try setting `eudc-strict-return-matches'\'' to nil or change `eudc-default-return-attributes'\''.\n"/""/g' $APP_PATH/${APP}.el

sed -i 's/"New query"/"新建查询"/g' $APP_PATH/${APP}.el
sed -i 's/"Quit"/"退出"/g' $APP_PATH/${APP}.el
sed -i 's/"Directory Server: "/"目录服务器: "/g' $APP_PATH/${APP}.el
sed -i 's/"Protocol: "/"协议: "/g' $APP_PATH/${APP}.el
sed -i 's/"Unsupported protocol: %s"/"不支持的协议: %s"/g' $APP_PATH/${APP}.el
sed -i 's/"Current directory server is now %s (%s)"/"当前的目录服务器当前 %s (%s)"/g' $APP_PATH/${APP}.el
sed -i 's/"Multiple match--use the query form"/"多个记录符合--使用查询表单"/g' $APP_PATH/${APP}.el
sed -i 's/"No record matching %s"/"没有匹配 %s 的记录"/g' $APP_PATH/${APP}.el
sed -i 's/"No match"/"不符合"/g' $APP_PATH/${APP}.el
sed -i 's/"Directory Query Form"/"目录查询表单"/g' $APP_PATH/${APP}.el

#
# insert some spaces to align
sed -i 's/"Protocol         : "/"协议             : "/g' $APP_PATH/${APP}.el
sed -i 's/"Current server is: "/"当前服务器        : "/g' $APP_PATH/${APP}.el
#
sed -i 's/"Query Server"/"查询服务器"/g' $APP_PATH/${APP}.el
sed -i 's/"Reset Form"/"复位表单"/g' $APP_PATH/${APP}.el
sed -i 's/"Query with Form"/"用表单进行查询"/g' $APP_PATH/${APP}.el
sed -i 's/"Expand Inline Query"/"展开联机查询"/g' $APP_PATH/${APP}.el
sed -i 's/"Insert Record into BBDB"/"插入记录到 BBDB 数据库"/g' $APP_PATH/${APP}.el
sed -i 's/"Insert All Records into BBDB"/"插入全部记录到 BBDB 数据库"/g' $APP_PATH/${APP}.el

sed -i 's/"Get Email"/"获取邮件"/g' $APP_PATH/${APP}.el
sed -i 's/"Get Phone"/"获取联系电话"/g' $APP_PATH/${APP}.el
sed -i 's/"List Valid Attribute Names"/"列出有效的属性名称"/g' $APP_PATH/${APP}.el
sed -i 's/"Customize"/"自定义"/g' $APP_PATH/${APP}.el
sed -i 's/"Bookmark Current Server"/"把当前服务器加入书签"/g' $APP_PATH/${APP}.el
sed -i 's/"Edit Server List"/"编辑服务器列表"/g' $APP_PATH/${APP}.el
sed -i 's/"New Server"/"新建服务器"/g' $APP_PATH/${APP}.el

# below may don't need to translate
sed -i 's/"Server"/"服务器"/g' $APP_PATH/${APP}.el
# end

sed -i 's/"Selected directory server is now %s (%s)"/"选中的目录服务当前 %s (%s)"/g' $APP_PATH/${APP}.el
sed -i 's/"Tools"/"工具"/g' $APP_PATH/${APP}.el
sed -i 's/"Directory Search"/"目录搜索"/g' $APP_PATH/${APP}.el
sed -i 's/"Unknown version of easymenu"/"未知版本的 easymenu"/g' $APP_PATH/${APP}.el
sed -i 's/"Load Hotlist of Servers"/"加载热门服务器列表"/g' $APP_PATH/${APP}.el
#sed -i 's/""/""/g' $APP_PATH/${APP}.el


### for windows
### link or copy translated .el file for windows dir
	echo
	echo "for $NAME_UPPER $2/Windows..."
cd ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/	
cp -pv $APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el
echo "Done."

## OPTIONAL MODULE
if [ $SHOW_TRANSED = "1" ];then
emacs -fw ~/${NAME_LOWER}-$2/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/usr/share/${NAME_LOWER}/$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el ~/${NAME_LOWER}-locale/windows/${NAME_LOWER}-$2/site-lisp/$3/lisp/$APP_PATH/${APP}.el &
fi
## MODULE END

	exit 0 ;;
    
    -h | --help)
	usage
	exit 0 ;;

    -v | --version)
	echo "$0 $VERSION"
	exit 0 ;;

    -*)
	echo "Unrecognized option \`$option'" 1>&2
	exit 1;;
    esac
done
exit 0;
exit 0;;
