;;; ui-zh-cn.el --- commands for toggle Simplified Chinese menu interface -*- coding: utf-8 -*-

;;; suggested path and filename: lisp/interface/ui-menu.el
;;; current path and filename: lisp/language/ui-menu.el
;;; because of the changes of separator code between since Emacs 23.2, we need
;;; another version for Emacs 23.1 and earlier versions 
;;;
;;; you can copy, modify and translate to: ui-zh-cn.el, ui-zh-tw.el and any 
;;; others...
;;; menu: Options => Toggle Menu Language => ...
;;; menu: Options => Enable Hot Settings => ...

;; Copyright (C) 2013 Careone <careone@wo.com.cn>.
;; License: LGPL V3 and/or BSD License

;; Author: Careone <careone@wo.com.cn>
;; Maintainer: 
;; Last Version: 0.26, for Emacs 23.1 and eailer versions
;; Current Version: 0.27, for Emacs 23.2 and later versions

;; Created: 2013-02-04
;; Keywords: interface, ui

;;; Commentary:

;;; Code:

(eval-when-compile
  (require 'cl))
(require 'tmm)

;; ;;;;;;;;;;;; customization variables ;;;;;;;;;;;;;;;;;;;;;;;;;

(defgroup interface nil
  "Toggle menu interface to other languages."
  :prefix "ui-"
  :group 'options)

(defcustom ui-en "English"
  "Toggle menu interface to English."
  :group 'interface
  :type 'string)

(defcustom ui-zh-cn "Simplified Chinese (zh_CN)"
  "Toggle menu interface to Simplified Chinese, China."
  :group 'interface
  :type 'string)

(defcustom ui-zh-tw "Traditional Chinese (zh_TW)"
  "Toggle menu interface to Traditional Chinese, Taiwan."
  :group 'interface
  :type 'string)

;; ;;;;;;;;;;;; customization variables end ;;;;;;;;;;;;;;;;;;;;;;;;;
 
;(or (lookup-key global-map [menu-bar])
;    (define-key global-map [menu-bar] (make-sparse-keymap "menu-bar")))

(defvar menu-bar-interface-menu (make-sparse-keymap "Toggle Menu Language"))
(defvar menu-bar-interface-en-menu (make-sparse-keymap "English"))
(defvar menu-bar-interface-zh-menu (make-sparse-keymap "Chinese"))

(defun ui-zh-cn-dos () 
  "for old Emacs/Windows 23.x and later: toggle menu interface to 
Simplified Chinese, China (zh_CN)"
(interactive)
(load-library "mule.zh_CN")
(load-library "mule.zh_CN.01codings_windows"))

(defun ui-zh-cn-old-dos () 
  "for old Emacs/Windows ? - 22.x: toggle menu interface to 
Simplified Chinese, China (zh_CN)"
(interactive)
(load-library "mule.zh_CN")
(load-library "mule.zh_CN.01codings-no-gb18030_windows"))

(defun ui-zh-cn-unix () 
  "for old Emacs/Unix 23.x and later: toggle menu interface to 
Simplified Chinese, China (zh_CN)"
(interactive)
(load-library "mule.zh_CN")
(load-library "mule.zh_CN.01codings_unix"))

(defun ui-zh-cn-old-unix () 
  "for old Emacs/Unix ? - 22.x: toggle menu interface to 
Simplified Chinese, China (zh_CN)"
(interactive)
(load-library "mule.zh_CN")
(load-library "mule.zh_CN.01codings-no-gb18030_unix"))

(defun ui-zh-cn () 
  "for old Emacs/Unix 23.x and later: toggle menu interface to 
Simplified Chinese, China (zh_CN)"
(interactive)
(load-library "mule.zh_CN")
;(load-library "mule.zh_CN.01codings_unix")
)

(defun ui-zh-cn-old () 
"for old Emacs/Unix ? - 22.x: toggle menu interface to 
Simplified Chinese, China (zh_CN)"
(interactive)
(load-library "mule.zh_CN")
;(load-library "mule.zh_CN.01codings-no-gb18030_unix")
)

;; todo
;
;(defun ui-zh-tw ()
;  "Traditional Chinese, Taiwan"
;(interactive)
;(load-library "mule.zh_TW"))
;
;; todo end

(defun ui-en () 
  "English "
(interactive)
;
;(load-library "86default-hot")
;
(load-library "menu-bar.elc")
(load-library "ui-zh-cn_new.orig")
)

(defun ui-en-old () 
  "English Old"
(interactive)
;
;(load-library "86default-hot")
;
(load-library "menu-bar.elc")
(load-library "ui-zh-cn_old.orig")
)

(define-key-after menu-bar-options-menu [separator-ui]
;;; IMPORTANT !!! 
;;; please write following menu-bar-separator) and ;'("--")) strings from the 
;;; first charactor place, or translate script sed.language_ui-xx-yy.sh
;;; can't auto convert this file to fit different Emacs versions.
;;;   and ;'("--")) which used for replace must write to one ; only, 
;;;   ;;'("--")) also can't be converted to fit different Emacs versions.

;; separator for newer Emacs 23.2 - ?
menu-bar-separator)
;
;; separator for old Emacs ? - 23.1
;'("--"))

(define-key-after menu-bar-options-menu [ui]
  `(menu-item ,(purecopy "Toggle Menu Language") ,menu-bar-interface-menu))

(define-key-after menu-bar-interface-menu [ui-en-menu]
  `(menu-item ,(purecopy "English") ,menu-bar-interface-en-menu))

(define-key-after menu-bar-interface-en-menu [ui-en]
  `(menu-item ,(purecopy "English for Emacs (>= 23.x)") ui-en
	      :help ,(purecopy "ui-en: English for Emacs 23.x and Later Versions")))

(define-key-after menu-bar-interface-en-menu [ui-en-old]
  `(menu-item ,(purecopy "English for Emacs (<= 22.x)") ui-en-old
	      :help ,(purecopy "ui-en-old: English for Emacs 22.x and Earlier Versions")))

(define-key-after menu-bar-interface-menu [separator-en]
;; separator for newer Emacs 23.2 - ?
menu-bar-separator)
;
;; separator for old Emacs ? - 23.1
;'("--"))

(define-key-after menu-bar-interface-menu [ui-zh-menu]
  `(menu-item ,(purecopy "Chinese") ,menu-bar-interface-zh-menu))
	      
(define-key-after menu-bar-interface-zh-menu [ui-zh-cn-unix]
  `(menu-item ,(purecopy "Simplified Chinese (zh_CN) for Unix Emacs (>= 23.x)") ui-zh-cn-unix
	      :help ,(purecopy "ui-zh-cn-unix: Simplified Chinese, China 
(zh_CN), for Unix Emacs 23.x and Later Versions")))

(define-key-after menu-bar-interface-zh-menu [ui-zh-cn-old-unix]
  `(menu-item ,(purecopy "Simplified Chinese (zh_CN) for Unix Emacs (<= 22.x)") ui-zh-cn-old-unix
	      :help ,(purecopy "ui-zh-cn-old-unix: Simplified Chinese, China 
(zh_CN), for Unix Emacs 22.x and Earlier Versions")))

(define-key-after menu-bar-interface-zh-menu [separator-unix]
;; separator for newer Emacs 23.2 - ?
menu-bar-separator)
;
;; separator for old Emacs ? - 23.1
;'("--"))

(define-key-after menu-bar-interface-zh-menu [ui-zh-cn-dos]
  `(menu-item ,(purecopy "Simplified Chinese (zh_CN) for Windows Emacs (>= 23.x)") ui-zh-cn-dos
	      :help ,(purecopy "ui-zh-cn-dos: Simplified Chinese, China 
(zh_CN), for Windows Emacs 23.x and Later Versions")))

(define-key-after menu-bar-interface-zh-menu [ui-zh-cn-old-dos]
  `(menu-item ,(purecopy "Simplified Chinese (zh_CN) for Windows Emacs (<= 22.x)") ui-zh-cn-old-dos
	      :help ,(purecopy "ui-zh-cn-old-dos: Simplified Chinese, China 
(zh_CN), for Windows Emacs 22.x and Earlier Versions")))

;; todo
;
;(define-key-after menu-bar-interface-zh-menu [ui-zh-tw]
;  `(menu-item ,(purecopy "Traditional Chinese (zh_TW)") ui-zh-tw
;	      :help ,(purecopy "Traditional Chinese, Taiwan (zh_TW)")))
;
;; todo end

(provide 'ui-zh-cn)

;; arch-tag: 
;;; ui-zh-cn.el ends here
